<?php
/**
 * Theme helper functions
 *
 * @package CoprTheme
 * @version 1.0.0
 */

/**
 * Flush rewrite rules for custom post types on theme activation
 */
add_action( 'after_switch_theme', 'copr_rewrite_rules_flush' );
function copr_rewrite_rules_flush() {
     flush_rewrite_rules();
}

/**
 * Wrap current page in span for wp_link_pages
 */
if ( ! function_exists( 'copr_wp_link_pages_wrap' ) ) {
	function copr_wp_link_pages_wrap( $link ) {
		if ( ctype_digit( $link ) ) {
			return '<span class="page-link-current">' . $link . '</span>';
		}
		return $link;
	}
	add_filter( 'wp_link_pages_link', 'copr_wp_link_pages_wrap' );
}

/**
 * Sanitize checkbox
 */
if ( ! function_exists( 'copr_sanitize_checkbox' ) ) {
	function copr_sanitize_checkbox( $input ) {
		if ( $input == 1 ) {
			return 1;
		} else {
			return '';
		}
	}
} // copr_sanitize_checkbox

/**
 * Sanitize select
 */
if ( ! function_exists( 'copr_sanitize_select' ) ) {
	function copr_sanitize_select( $input, $setting ){
		$input = sanitize_key($input);
		$choices = $setting->manager->get_control( $setting->id )->choices;
		return ( array_key_exists( $input, $choices ) ? $input : $setting->default );                
	}
}

/**
 * Sanitize image upload
 */
if ( ! function_exists( 'copr_sanitize_image' ) ) {
	function copr_sanitize_image( $file, $setting ) {
	  
		//allowed file types
		$mimes = array(
			'jpg|jpeg|jpe' => 'image/jpeg',
			'gif'          => 'image/gif',
			'png'          => 'image/png'
		);
		  
		//check file type from file name
		$file_ext = wp_check_filetype( $file, $mimes );
		  
		//if file has a valid mime type return it, otherwise return default
		return ( $file_ext['ext'] ? $file : $setting->default );
	}
}

// core plugin update notice
if ( ! function_exists( 'copr_core_update_admin_notice' ) ) {
	function copr_core_update_admin_notice() {
		if ( is_admin() ) {
			if( !function_exists('get_plugin_data') ){
				require_once( ABSPATH . 'wp-admin/includes/plugin.php' );
			}
			if ( !class_exists( 'dtr_copr_core' ) ) return;
			$copr_core_plugin_dir = WP_PLUGIN_DIR . '/dtr-copr-core/dtr-copr-core.php';
			$copr_core_plugin_data = get_plugin_data($copr_core_plugin_dir);
			$copr_core_plugin_version = $copr_core_plugin_data['Version'];
			if ( $copr_core_plugin_version < COPR_CORE_PLUGIN_CURRENT_VERSION ) { ?>
				<div class="notice notice-error"><p><?php _e( '<strong>Important</strong> : Update Copr Core Plugin. Go To : Appearance / Install Plugins', 'copr' ); ?></p></div>
			<?php }
		}
	}
}
add_action( 'admin_notices', 'copr_core_update_admin_notice' );

// elementor addon plugin update notice
if ( ! function_exists( 'copr_elementor_addon_update_admin_notice' ) ) {
	function copr_elementor_addon_update_admin_notice() {
		if ( is_admin() ) {
			if( !function_exists('get_plugin_data') ){
				require_once( ABSPATH . 'wp-admin/includes/plugin.php' );
			}
			if ( !class_exists( '\CoprAddons\Copr_Elementor_Addons' ) ) return;
			$copr_elementor_addon_plugin_dir = WP_PLUGIN_DIR . '/dtr-copr-elementor-addon/dtr-copr-elementor.php';
			$copr_elementor_addon_plugin_data = get_plugin_data($copr_elementor_addon_plugin_dir);
			$copr_elementor_addon_plugin_version = $copr_elementor_addon_plugin_data['Version'];
			if ( $copr_elementor_addon_plugin_version < COPR_ELEMENTOR_ADDON_PLUGIN_CURRENT_VERSION ) { ?>
            	<div class="notice notice-error"><p><?php _e( '<strong>Important</strong> : Update Copr Elementor Addons Plugin Plugin. Go To : Appearance / Install Plugins', 'copr' ); ?></p></div>
			<?php }
		}
	}
}
add_action( 'admin_notices', 'copr_elementor_addon_update_admin_notice' );

// import Notice
if ( true == get_theme_mod( 'copr_demo_import_notification_enable', true ) ) { 
	if ( ! function_exists( 'copr_demo_import_notice' ) ) {
		function copr_demo_import_notice() {
			?>
			<div class="notice notice-error is-dismissible dtr-import-notice">
            	<h4><?php _e( '** Theme SetUp Guide for New Buyers **', 'copr' ); ?></h4>
            	<h5><?php _e( 'Step 1: Install All Required / Recommended Plugins', 'copr' ); ?></h5>
              <p><?php _e( 'There is a link to install plugins in below Notice OR <strong>Visit : Appearance > Install Plugins</strong>', 'copr' ); ?></p>
            	<h5><?php _e( 'Step 2: Import Theme Demo Data', 'copr' ); ?></h5>
				<p><?php _e( 'As WordPress Themes do not carry data with them...Import Demo Data to make your link look like Theme Demo.<br> <strong>Visit : Appearance > Import Theme Demo Data</strong>', 'copr' ); ?></h5>
                <h5><?php _e( 'Step 3: Online Help Documentation', 'copr' ); ?></h5>
                <p><?php _e( 'Find online help document here : <a class="button button-primary" href="https://docs.tanshcreative.com/copr" target="_blank">Online Help Documentation</a>', 'copr' ); ?></p>
                <h5><?php _e( 'Step 4: Disable this Notification', 'copr' ); ?></h5>
                <p><?php _e( 'If you have finished importing demo data...<strong>Permanently Disable</strong> this Demo Import and Import Plugin Install <strong>Notice</strong> ( Customizer > Misc > Demo Import Notice )', 'copr' ); ?></h5><br>
                <a class="button button-primary" href="<?php echo admin_url( '/customize.php?autofocus[panel]=copr_panel_misc&autofocus[section]=copr_section_demo_import_settings' ) ?>"><?php _e( 'Disable This Notice', 'copr' ); ?></a>
			</div>
			<?php
		}
		add_action( 'admin_notices', 'copr_demo_import_notice' );
	}
}

// admin styles
if ( true == get_theme_mod( 'copr_demo_import_notification_enable', true ) ) { 
	if ( ! function_exists( 'copr_import_notice_admin_css' ) ) {
		function copr_import_notice_admin_css() {
		  echo '<style>
			.dtr-import-notice { background-color: #f5eae6; border-color: #f5eae6; border-left-color: #4A060D; color: #4A060D; }
			.dtr-import-notice h4 { font-size: 1.4em; }
			.dtr-import-notice h5 { font-size: 1.2em; margin-bottom: 10px; }
			.dtr-import-notice p { font-size: 1em; }
			.dtr-import-notice .button { margin-top: 10px; }
		  </style>';
		}
		add_action('admin_head', 'copr_import_notice_admin_css'); 
	}
}