<?php
namespace CoprAddons;

use CoprAddons\Widgets\Copr_Iconhead;
use CoprAddons\Widgets\Copr_Feature;
use CoprAddons\Widgets\Copr_Button;
use CoprAddons\Widgets\Copr_About;
use CoprAddons\Widgets\Copr_Counter;
use CoprAddons\Widgets\Copr_Rotating_Image;
use CoprAddons\Widgets\Copr_Timeline;
use CoprAddons\Widgets\Copr_Skills;
use CoprAddons\Widgets\Copr_Animated_Heading;
use CoprAddons\Widgets\Copr_Blockquote;
use CoprAddons\Widgets\Copr_Icon;
use CoprAddons\Widgets\Copr_Testimonial_Carousel;
use CoprAddons\Widgets\Copr_Recentposts_Carousel;
use CoprAddons\Widgets\Copr_Pricing;
use CoprAddons\Widgets\Copr_Clients;
use CoprAddons\Widgets\Copr_Servicebox;
use CoprAddons\Widgets\Copr_Servicebox_Var;
use CoprAddons\Widgets\Copr_Portfolio;

if ( ! defined( 'ABSPATH' ) ) exit; // Exit if accessed directly
/**
 * Main Plugin Class
 * Register new elementor widget.
 * @since 1.0.0
 */
class Copr_Elementor_Addons {
	
	/**
	 * Minimum Elementor Version
	 * @var string Minimum Elementor version required to run the plugin.
	 */
	const MINIMUM_ELEMENTOR_VERSION = '2.0.0';

	/**
	 * Constructor
	 * @since 1.0.0
	 * @access public
	 */
	public function __construct() {
		$this->add_actions();
		$this->setup_hooks();
	}
	
	/**
	 * Add Actions
	 * @since 1.0.0
	 * @access private
	 */
	
	public function add_actions() {
		add_action( 'elementor/widgets/register', [ $this, 'on_widgets_registered' ] );
		add_action( 'elementor/init', array( $this, 'add_elementor_category' ) );
		
		// Check if Elementor installed and activated
		if ( ! did_action( 'elementor/loaded' ) ) {
			add_action( 'admin_notices', [ $this, 'admin_notice_missing_main_plugin' ] );
			return;
		}
		
		// Check for required Elementor version
		if ( ! version_compare( ELEMENTOR_VERSION, self::MINIMUM_ELEMENTOR_VERSION, '>=' ) ) {
			add_action( 'admin_notices', [ $this, 'admin_notice_minimum_elementor_version' ] );
			return;
		}
		
	}

	/**
	 * Admin notice
	 * Warning when the site doesn't have Elementor installed or activated.
	 * @access public
	 */
	public function admin_notice_missing_main_plugin() {
		if ( isset( $_GET['activate'] ) ) unset( $_GET['activate'] );
		$message = sprintf(
			/* translators: 1: Plugin name 2: Elementor */
			esc_html__( '"%1$s" requires "%2$s" to be installed and activated.', 'copr' ),
			'<strong>' . esc_html__( 'Copr Elementor Addons', 'copr' ) . '</strong>',
			'<strong>' . esc_html__( 'Elementor', 'copr' ) . '</strong>'
		);
		printf( '<div class="notice notice-warning is-dismissible"><p>%1$s</p></div>', $message );
	}
	
	/**
	 * Admin notice
	 * Warning when the site doesn't have a minimum required Elementor version.
	 * @access public
	 */
	public function admin_notice_minimum_elementor_version() {

		if ( isset( $_GET['activate'] ) ) unset( $_GET['activate'] );

		$message = sprintf(
			/* translators: 1: Plugin name 2: Elementor 3: Required Elementor version */
			esc_html__( '"%1$s" requires "%2$s" version %3$s or greater.', 'copr' ),
			'<strong>' . esc_html__( 'Copr Elementor Addons', 'copr' ) . '</strong>',
			'<strong>' . esc_html__( 'Elementor', 'copr' ) . '</strong>',
			 self::MINIMUM_ELEMENTOR_VERSION
		);

		printf( '<div class="notice notice-warning is-dismissible"><p>%1$s</p></div>', $message );

	}

	/**
	 * Add setup_hooks
	 * @since 1.0.0
	 * @access private
	 */
	private function setup_hooks() {
		// Register Widget Styles
		add_action( 'elementor/editor/after_enqueue_styles', [ $this, 'widget_styles' ] );
		add_action( 'elementor/frontend/after_register_scripts',[ $this, 'register_frontend_scripts' ], 10 );
	}
	
	/**
	 * On Widgets Registered
	 * @since 1.0.0
	 * @access public
	 */
	public function on_widgets_registered() {
		$this->includes();
		$this->register_widget();
	}
	
	/**
	 * Add Category
	 * @since 1.0.0
	 * @access public
	 */
	 public function add_elementor_category() {
		\Elementor\Plugin::instance()->elements_manager->add_category(
			'dtr-element',
			array(
				'title' => __('Copr Addons', 'copr'),
				'icon' => 'fa fa-plug',
			),
			1);
      }

	/**
	 * Includes
	 * @since 1.0.0
	 * @access private
	 */
	private function includes() {
		
		require __DIR__ . '/widgets/dtr-icon-heading.php';
		require __DIR__ . '/widgets/dtr-feature.php';
		require __DIR__ . '/widgets/dtr-button.php';
		require __DIR__ . '/inc/dtr-icons.php';
		require __DIR__ . '/widgets/dtr-about.php';
		require __DIR__ . '/widgets/dtr-counter.php';
		require __DIR__ . '/widgets/dtr-rotating-image.php';
		require __DIR__ . '/widgets/dtr-timeline.php';
		require __DIR__ . '/widgets/dtr-skills.php';
		require __DIR__ . '/widgets/dtr-animated-heading.php';
		require __DIR__ . '/widgets/dtr-blockquote.php';
		require __DIR__ . '/widgets/dtr-icon.php';
		require __DIR__ . '/widgets/dtr-testimonial-carousel.php';
		require __DIR__ . '/widgets/dtr-recentposts-carousel.php';
		require __DIR__ . '/widgets/dtr-pricing.php';
		require __DIR__ . '/widgets/dtr-clients.php';
		require __DIR__ . '/widgets/dtr-servicebox.php';
        require __DIR__ . '/widgets/dtr-servicebox-var.php';
		require __DIR__ . '/widgets/dtr-portfolio.php';
	}

	/**
	 * Register Widget
	 * @since 1.0.0
	 * @access private
	 */
	private function register_widget() {
		\Elementor\Plugin::instance()->widgets_manager->register( new Copr_Iconhead() );
		\Elementor\Plugin::instance()->widgets_manager->register( new Copr_Feature() );
		\Elementor\Plugin::instance()->widgets_manager->register( new Copr_Button() );
		\Elementor\Plugin::instance()->widgets_manager->register( new Copr_About() );
		\Elementor\Plugin::instance()->widgets_manager->register( new Copr_Counter() );
		\Elementor\Plugin::instance()->widgets_manager->register( new Copr_Rotating_Image() );
		\Elementor\Plugin::instance()->widgets_manager->register( new Copr_Timeline() );
		\Elementor\Plugin::instance()->widgets_manager->register( new Copr_Skills() );	
		\Elementor\Plugin::instance()->widgets_manager->register( new Copr_Animated_Heading() );
		\Elementor\Plugin::instance()->widgets_manager->register( new Copr_Blockquote() );
		\Elementor\Plugin::instance()->widgets_manager->register( new Copr_Icon() );
		\Elementor\Plugin::instance()->widgets_manager->register( new Copr_Testimonial_Carousel() );
		\Elementor\Plugin::instance()->widgets_manager->register( new Copr_Recentposts_Carousel() );
		\Elementor\Plugin::instance()->widgets_manager->register( new Copr_Pricing() );
		\Elementor\Plugin::instance()->widgets_manager->register( new Copr_Clients() );
		\Elementor\Plugin::instance()->widgets_manager->register( new Copr_Servicebox() );
        \Elementor\Plugin::instance()->widgets_manager->register( new Copr_Servicebox_Var() );
		\Elementor\Plugin::instance()->widgets_manager->register( new Copr_Portfolio() );
	}
	
	/**
	 * enqueue styles
	 * @since 1.0.0
	 * @access public
	 */
	public function widget_styles() {
		
		wp_enqueue_style( 'dtr-custom-icons', COPR_ELEMENTOR_ADDONS_URL . 'fonts/iconfont.css' );
		
		// elementor pro css mod
		$elementor_pro_mod = '';
		$elementor_pro_mod = get_theme_mod( 'copr_elementor_pro_mod', 'yes' );
		if ( $elementor_pro_mod == 'yes' && ! class_exists( 'ElementorPro\Plugin' ) ) {
			wp_enqueue_style( 'dtr-elementor-pro-mod', COPR_ELEMENTOR_ADDONS_URL . 'assets/css/elementor-pro-mod.css' );
		}
	}
	
	/**
	 * Load Frontend Scripts
	 *
	 */
	public function register_frontend_scripts() {
		wp_register_script( 'swiper', COPR_ELEMENTOR_ADDONS_URL . 'assets/js/swiper-bundle.min.js', array('jquery'), '5.0.3', true );
		wp_register_script( 'dtr-widgets', COPR_ELEMENTOR_ADDONS_URL . 'assets/js/dtr-widgets.js', array('jquery'), '1.0', true );
		wp_enqueue_style( 'font-awesome-5-all', ELEMENTOR_ASSETS_URL . 'lib/font-awesome/css/all.min.css' );
    } 
	
}
new Copr_Elementor_Addons();