<?php
namespace CoprAddons\Widgets;
use Elementor\Widget_Base;
use Elementor\Controls_Manager;
use Elementor\Utils;
use Elementor\Control_Media;
use Elementor\Group_Control_Typography;
use Elementor\Group_Control_Image_Size;

if ( ! defined( 'ABSPATH' ) ) {
	exit; // Exit if accessed directly.
}
/**
 * About Widget
 */
class Copr_About extends Widget_Base {

	/**
	 * Retrieve widget name.
	 * @access public
	 * @return string Widget name.
	 */
	public function get_name() {
		return 'dtr-about';
	}

	/**
	 * Retrieve widget title.
	 * @access public
	 * @return string Widget title.
	 */
	public function get_title() {
		return esc_html__( 'About Me', 'copr' );
	}

	/**
	 * Retrieve widget icon.
	 * @access public
	 * @return string Widget icon.
	 */
	public function get_icon() {
		return 'eicon-favorite';
	}

	/**
	 * Retrieve the list of categories widget belongs to.
	 * Used to determine where to display the widget in the editor.
	 * @access public
	 * @return array Widget categories.
	 */
	public function get_categories() {
		  return array('dtr-element');

	}

	/**
	 * Register widget controls.
	 * Adds different input fields to allow the user to change and customize the widget settings.
	 * @access protected
	 */
	protected function register_controls() {
		
		// image control starts
		$this->start_controls_section(
			'section_about_image',
			[
				'label'	=> esc_html__( 'About Me', 'copr' ),
			]
		);

		$this->add_control(
			'about_image_control',
			[
				'label' => esc_html__( 'Image', 'copr' ),
				'type' => Controls_Manager::HEADING,
				'separator' => 'before',
			]
		);		
		$this->add_control(
			'image',
			[
				'label' 	=> esc_html__( 'Choose Image', 'copr' ),
				'type' 		=> Controls_Manager::MEDIA,
				'default'	=> [
					'url'	=> Utils::get_placeholder_image_src(),
				],
			]
		);
		
		$this->add_group_control(
			Group_Control_Image_Size::get_type(),
			[
				'name' 		=> 'thumbnail',
				'default' 	=> 'full',
				'separator'	=> 'none',
			]
		);
		
		$this->add_control(
			'about_title',
			[
				'label' 		=> esc_html__( 'Title', 'copr' ),
				'type' 			=> Controls_Manager::TEXT,
				'default' 		=> esc_html__( 'Title Goes Here', 'copr' ),
				'placeholder'	=> esc_html__( 'Title', 'copr' ),
				'label_block' 	=> true,
				'separator' 	=> 'before',
			]
		);

		$this->add_control(
			'about_subtext',
			[
				'label' 		=> esc_html__( 'Sub Text', 'copr' ),
				'type' 			=> Controls_Manager::TEXT,
				'default' 		=> esc_html__( 'Sub text Goes Here', 'copr' ),
				'placeholder'	=> esc_html__( 'Sub Text', 'copr' ),
				'label_block' 	=> true,
			]
		);

		$this->add_control(
			'view',
			[
				'label' 	=> esc_html__( 'View', 'copr' ),
				'type' 		=> Controls_Manager::HIDDEN,
				'default'	=> 'traditional',
			]
		);
		
		$this->end_controls_section();

		// style control starts
		$this->start_controls_section(
			'section_style_content',
			[
				'label'	=> esc_html__( 'Styles', 'copr' ),
				'tab'   => Controls_Manager::TAB_STYLE,
			]
		);

		// heading
		$this->add_control(
			'heading_style',
			[
				'label' => esc_html__( 'Heading', 'copr' ),
				'type' 	=> Controls_Manager::HEADING,
				'separator' => 'before',
			]
		);
		
		$this->add_control(
			'heading_color',
			[
				'label' 	=> esc_html__( 'Color', 'copr' ),
				'default' 	=> '',
				'type' 		=> Controls_Manager::COLOR,
				'selectors'	=> [
					'{{WRAPPER}} .dtr-about__heading'	=> 'color: {{VALUE}};',
				],
			]
		);
		
		$this->add_control(
			'heading_bg_color',
			[
				'label' 	=> esc_html__( 'Background Color', 'copr' ),
				'default' 	=> '',
				'type' 		=> Controls_Manager::COLOR,
				'selectors'	=> [
					'{{WRAPPER}} .dtr-about__heading'	=> 'background-color: {{VALUE}};',
				],
			]
		);
		
		$this->add_group_control(
            Group_Control_Typography::get_type(),
            [
                'name' 		=> 'main_heading_typo',
				'label' 	=> esc_html__( 'Typography', 'copr' ),
                'selector'	=> '{{WRAPPER}} .dtr-about__heading',
            ]
        );

		// sub text
		$this->add_control(
			'subtext_style',
			[
				'label' => esc_html__( 'Sub Text', 'copr' ),
				'type' 	=> Controls_Manager::HEADING,
				'separator' => 'before',
			]
		);
		
		$this->add_control(
			'subtext_color',
			[
				'label' 	=> esc_html__( 'Color', 'copr' ),
				'default' 	=> '',
				'type' 		=> Controls_Manager::COLOR,
				'selectors'	=> [
					'{{WRAPPER}} .dtr-about__subtext'	=> 'color: {{VALUE}};',
				],
			]
		);
		
		$this->add_control(
			'subtext_bg_color',
			[
				'label' 	=> esc_html__( 'Background', 'copr' ),
				'default' 	=> '',
				'type' 		=> Controls_Manager::COLOR,
				'selectors'	=> [
					'{{WRAPPER}} .dtr-about__subtext'	=> 'background-color: {{VALUE}};',
				],
			]
		);
		
		$this->add_group_control(
            Group_Control_Typography::get_type(),
            [
                'name' 		=> 'subtext_typo',
				'label' 	=> esc_html__( 'Typography', 'copr' ),
                'selector'	=> '{{WRAPPER}} .dtr-about__subtext',
            ]
        );
		
		$this->end_controls_section();
		// style control ends
	}

	/**
	 * Render widget output on the frontend.
	 * Written in PHP and used to generate the final HTML.
	 * @access protected
	 */
	protected function render() {
		$settings = $this->get_settings();
	  	?>
<div class="dtr-about">
        <?php
		$this->add_render_attribute( 'image', 'src', $settings['image']['url'] );
		$this->add_render_attribute( 'image', 'alt', Control_Media::get_image_alt( $settings['image'] ) );
		$this->add_render_attribute( 'image', 'title', Control_Media::get_image_title( $settings['image'] ) );
		$image_html = Group_Control_Image_Size::get_attachment_image_html( $settings, 'thumbnail', 'image' ); ?>
        <figure class="dtr-about__img"><?php echo $image_html ?></figure>
	<div class="dtr-about__content">
    	<h6 class="dtr-about__heading"><?php echo esc_html( $settings['about_title'] ) ?></h6>
        <span class="clearfix"></span>
     	<span class="dtr-about__subtext"><?php echo esc_html( $settings['about_subtext'] ) ?></span>
    </div>
</div>
<?php
	}

	/**
	 * Render widget output in the editor.
	 * Written as a Backbone JavaScript template and used to generate the live preview.
	 * @access protected
	 */
	protected function content_template() {
		?>
<div class="dtr-about">
	<#	if ( settings.image.url ) { #>
        <# var image = {
        id: settings.image.id,
        url: settings.image.url,
        size: settings.thumbnail_size,
        dimension: settings.thumbnail_custom_dimension,
        model: view.getEditModel() };
        var image_url = elementor.imagesManager.getImageUrl( image );  #><figure class="dtr-about__img"><img src="{{ image_url }}"/></figure>
    <# } #>
    <div class="dtr-about__content">
    	<h6 class="dtr-about__heading">{{{settings.about_title }}}</h6>
        <span class="clearfix"></span>
		<span class="dtr-about__subtext">{{{settings.about_subtext }}}</span>
    </div>
</div>
<?php
	}
}