<?php
namespace CoprAddons\Widgets;

use Elementor\Widget_Base;
use Elementor\Controls_Manager;
use Elementor\Utils;
use Elementor\Group_Control_Typography;
use Elementor\Control_Media;
use Elementor\Group_Control_Image_Size;

if ( ! defined( 'ABSPATH' ) ) {
	exit; // Exit if accessed directly.
}

/**
 * Widget
 */
class Copr_Clients extends Widget_Base {

	/**
	 * Retrieve widget name.
	 * @access public
	 * @return string Widget name.
	 */
	public function get_name() {
		return 'dtr-clients';
	}

	/**
	 * Retrieve widget title.
	 * @access public
	 * @return string Widget title.
	 */
	public function get_title() {
		return esc_html__( 'Clients', 'copr' );
	}

	/**
	 * Retrieve widget icon.
	 * @access public
	 * @return string Widget icon.
	 */
	public function get_icon() {
		return 'eicon-favorite';
	}

	/**
	 * Retrieve the list of categories widget belongs to.
	 * Used to determine where to display the widget in the editor.
	 * @access public
	 * @return array Widget categories.
	 */
	public function get_categories() {
		return array('dtr-element');
	}
	

	/**
	 * Register widget controls.
	 * Adds different input fields to allow the user to change and customize the widget settings.
	 * @access protected
	 */
	protected function register_controls() {
	
		// content control starts
		$this->start_controls_section(
			'section_client_content',
			[
				'label'	=> esc_html__( 'Clients', 'copr' ),
			]
		);
		
		//
		$this->add_control(
			'box_height',
			[
				'label' => esc_html__( 'Box Height (px)', 'copr' ),
				'type' => Controls_Manager::SLIDER,
				'default' => [
					'size' => '',
					'size_units' => 'px',
				],
				'size_units' => [ 'px' ],
				'selectors' => [
					'{{WRAPPER}} .dtr-client-box' => 'height: {{SIZE}}{{UNIT}};',
				],
			]
		);
		
		// image
		$this->add_control(
			'clients_image_control',
			[
				'label' 	=> esc_html__( 'Image', 'copr' ),
				'type' 		=> Controls_Manager::HEADING,
				'separator'	=> 'before',
			]
		);		
		$this->add_control(
			'image',
			[
				'label' 	=> esc_html__( 'Choose Image', 'copr' ),
				'type' 		=> Controls_Manager::MEDIA,
				'default'	=> [
					'url'	=> COPR_ELEMENTOR_ADDONS_URL . 'assets/img/img-circle-100x100.png',
				],
			]
		);
		
		$this->add_group_control(
			Group_Control_Image_Size::get_type(),
			[
				'name' 		=> 'thumbnail',
				'default' 	=> 'full',
				'separator'	=> 'none',
			]
		);

		// heading
		$this->add_control(
			'clients_heading',
			[
				'label' 		=> esc_html__( 'Heading', 'copr' ),
				'type' 			=> Controls_Manager::TEXT,
				'default' 		=> esc_html__( 'Inspire', 'copr' ),
				'placeholder' 	=> esc_html__( 'Your Heading', 'copr' ),
				'label_block' 	=> true,
				'separator'	 	=> 'before',
			]
		);
		
		$this->add_control(
			'heading_size',
			[
				'label' 	=> esc_html__( 'Heading - HTML Tag', 'elementor' ),
				'type' 		=> Controls_Manager::SELECT,
				'options'	=> [
					'h1' 	=> 'H1',
					'h2' 	=> 'H2',
					'h3' 	=> 'H3',
					'h4' 	=> 'H4',
					'h5' 	=> 'H5',
					'h6'	=> 'H6',
					'p' 	=> 'p',
				],
				'default' => 'h5',
			]
		);
		
		// content
		$this->add_control(
			'clients_content',
			[
				'label' 		=> esc_html__( 'Content', 'copr' ),
				'type' 			=> Controls_Manager::TEXTAREA,
				'default' 		=> esc_html__( 'Lorem ipsum dolor sit amet consectetur adipiscing labore et dolore magna aliqua. ', 'copr' ),
				'separator'		=> 'before',
				'placeholder' 	=> esc_html__( 'Your Content', 'copr' ),
				'label_block' 	=> true,
			]
		);

		// link
		$this->add_control(
			'link_control',
			[
				'label' 	=> esc_html__( 'Link', 'copr' ),
				'type' 		=> Controls_Manager::HEADING,
				'separator'	=> 'before',
			]
		);		

		$this->add_control(
			'link',
			[
				'label' 		=> esc_html__( 'Link', 'copr' ),
				'type' 			=> Controls_Manager::URL,
				'placeholder'	=> 'http://your-link.com',
				'default' 		=> [
					'url'	=> '#',
				],
			]
		);
		
		$this->add_control(
			'link_aria_label',
			[
				'label' 		=> esc_html__( 'Area label For Link', 'copr' ),
				'type' 			=> Controls_Manager::TEXT,
				'default' 		=> esc_html__( 'Read More', 'copr' ),
				'placeholder' 	=> esc_html__( 'Read More', 'copr' ),
				'label_block' 	=> true,
				'separator'	 	=> 'before',
			]
		);
				
		$this->add_control(
			'view',
			[
				'label' 	=> esc_html__( 'View', 'copr' ),
				'type' 		=> Controls_Manager::HIDDEN,
				'default'	=> 'traditional',
			]
		);
		
		$this->end_controls_section();
		// content control ends

		// style control starts
		$this->start_controls_section(
			'section_client_styles',
			[
				'label' => esc_html__( 'Styles', 'copr' ),
				'tab'   => Controls_Manager::TAB_STYLE,
			]
		);
		
		// background
		$this->add_control(
			'bg_control',
			[
				'label' 	=> esc_html__( 'Background', 'copr' ),
				'type' 		=> Controls_Manager::HEADING,
				'separator'	=> 'before',
			]
		);		
		
		$this->add_control(
			'bg_color',
			[
				'label' 	=> esc_html__( 'Background Color', 'copr' ),
				'type' 		=> Controls_Manager::COLOR,
				'default' 	=> '',
				'selectors'	=> [
					'{{WRAPPER}} .dtr-client-box'	=> 'background-color: {{VALUE}};',
				],
			]
		);
		
		$this->add_control(
			'bg_hover_control',
			[
				'label' 	=> esc_html__( 'On Hover Content', 'copr' ),
				'type' 		=> Controls_Manager::HEADING,
				'separator'	=> 'before',
			]
		);	
		
		$this->add_control(
			'preset_color_scheme',
			[
				'label' 	=> esc_html__( 'Preset Color Scheme', 'copr' ),
				'type'		=> Controls_Manager::SELECT,
				'default'	=> '',
				'options' 	=> [
					''								=> esc_html__( 'Color Scheme 1 - Secondary Color Background', 'copr' ),
					'dtr-client-box--clr-scheme2'	=> esc_html__( 'Color Scheme 2 - Primary Color Background', 'copr' ),
				],
			]
		);
		
		$this->add_control(
			'hover_bg_color',
			[
				'label' 	=> esc_html__( 'Background Color', 'copr' ),
				'type' 		=> Controls_Manager::COLOR,
				'default' 	=> '',
				'selectors'	=> [
					'{{WRAPPER}} .dtr-client-box__hover-content'	=> 'background-color: {{VALUE}}; color: {{VALUE}};',
				],
			]
		);	
		
		// heading
		$this->add_control(
			'heading_style_control',
			[
				'label' 	=> esc_html__( 'Heading', 'copr' ),
				'type' 		=> Controls_Manager::HEADING,
				'separator'	=> 'before',
			]
		);
		
		$this->add_control(
			'heading_color',
			[
				'label' 	=> esc_html__( 'Heading', 'copr' ),
				'type' 		=> Controls_Manager::COLOR,
				'default' 	=> '',
				'selectors'	=> [
					'{{WRAPPER}} .dtr-client-box__heading'	=> 'color: {{VALUE}};',
				],
			]
		);
	
		$this->add_group_control(
            Group_Control_Typography::get_type(),
            [
                'name' 		=> 'heading_typo',
				'label' 	=> esc_html__( 'Typography', 'copr' ),
                'selector' 	=> '{{WRAPPER}} .dtr-client-box__heading',
            ]
        );

		// content
		$this->add_control(
			'content_style_control',
			[
				'label' 	=> esc_html__( 'Content', 'copr' ),
				'type' 		=> Controls_Manager::HEADING,
				'separator'	=> 'before',
			]
		);
		
		$this->add_control(
			'content_color',
			[
				'label' 	=> esc_html__( 'Content', 'copr' ),
				'type' 		=> Controls_Manager::COLOR,
				'default' 	=> '',
				'selectors'	=> [
					'{{WRAPPER}} .dtr-client-box__text'	=> 'color: {{VALUE}};',
				],
			]
		);
	
		$this->add_group_control(
            Group_Control_Typography::get_type(),
            [
                'name' 		=> 'content_typo',
				'label' 	=> esc_html__( 'Typography', 'copr' ),
                'selector' 	=> '{{WRAPPER}} .dtr-client-box__text',
            ]
        );

		// content
		$this->add_control(
			'link_style_control',
			[
				'label' 	=> esc_html__( 'Link', 'copr' ),
				'type' 		=> Controls_Manager::HEADING,
				'separator'	=> 'before',
			]
		);

		$this->add_control(
			'link_color',
			[
				'label' 	=> esc_html__( 'Color', 'copr' ),
				'type' 		=> Controls_Manager::COLOR,
				'default' 	=> '',
				'selectors'	=> [
					'{{WRAPPER}} .dtr-client-box__link'	=> 'color: {{VALUE}};',
				],
			]
		);

		$this->end_controls_section();
		// style control ends
		
	}

	/**
	 * Render widget output on the frontend.
	 * Written in PHP and used to generate the final HTML.
	 * @access protected
	 */
	protected function render() {
		$settings = $this->get_settings();
		// button
		if ( ! empty( $settings['link']['url'] ) ) {
			$this->add_link_attributes( 'button', $settings['link'] );
			$this->add_render_attribute( 'button', 'class', 'dtr-client-box__link' );
		}
		$this->add_render_attribute( 'button', 'role', 'button' ); ?>
        <div class="dtr-client-box <?php echo esc_attr( $settings['preset_color_scheme'] ) ?>">
<div class="dtr-client-box__content clearfix">
		<?php
                $this->add_render_attribute( 'image', 'src', $settings['image']['url'] );
                $this->add_render_attribute( 'image', 'alt', Control_Media::get_image_alt( $settings['image'] ) );
                $this->add_render_attribute( 'image', 'title', Control_Media::get_image_title( $settings['image'] ) );
                $image_html = Group_Control_Image_Size::get_attachment_image_html( $settings, 'thumbnail', 'image' ); ?>
                <?php echo $image_html ?>
            </div>
            <div class="dtr-client-box__hover-content">
				<?php if ( ! empty( $settings['clients_heading'] ) ) { ?>
                	<<?php echo esc_attr( $settings['heading_size'] ) ?> class="dtr-client-box__heading"><?php echo wp_kses_post( $settings['clients_heading'] ) ?></<?php echo esc_attr( $settings['heading_size'] ) ?>>
                <?php } ?>
                <?php if ( ! empty( $settings['clients_content'] ) ) { ?>
                	<div class="dtr-client-box__text"><?php echo wp_kses_post( $settings['clients_content'] ) ?></div>
                <?php } ?>
                <?php if ( ! empty( $settings['link']['url'] ) ) { ?>
                	<a <?php echo $this->get_render_attribute_string( 'button' ); ?> aria-label="<?php echo esc_attr( $settings['link_aria_label'] ) ?>"></a>
                <?php } ?>
            </div>
        </div>
<?php
		}
	
		/**
		 * Render widget output in the editor.
		 * Written as a Backbone JavaScript template and used to generate the live preview.
		 * @access protected
		 */
		protected function content_template() {
		?>
        <div class="dtr-client-box {{{settings.preset_color_scheme }}}">
            <div class="dtr-client-box__content">
                <#
                var image = {
                id: settings.image.id,
                url: settings.image.url,
                size: settings.thumbnail_size,
                dimension: settings.thumbnail_custom_dimension,
                model: view.getEditModel()
                };
                var image_url = elementor.imagesManager.getImageUrl( image );  #> <img src="{{ image_url }}"/> 
            </div>
            <div class="dtr-client-box__hover-content">
                <# if ( settings.clients_heading ) { #>
                <{{ settings.heading_size }} class="dtr-client-box__heading">{{{ settings.clients_heading }}}</{{ settings.heading_size }}>
                <# } #>
                <# if ( settings.clients_content ) { #>
                <div class="dtr-client-box__text">{{{ settings.clients_content }}}</div>
                <# } #>
                <#	if ( settings.link.url ) { #>
                <a class="dtr-client-box__link" href="{{ settings.link.url }}" role="button"></a>
                <# } #> 
            </div>
        </div>
        <?php
	}
}