<?php
namespace CoprAddons\Widgets;
use Elementor\Widget_Base;
use Elementor\Controls_Manager;
use Elementor\Utils;
use Elementor\Group_Control_Typography;

if ( ! defined( 'ABSPATH' ) ) {
	exit; // Exit if accessed directly.
}
/**
 * Counter Widget
 */
class Copr_Counter extends Widget_Base {

	/**
	 * Retrieve widget name.
	 * @access public
	 * @return string Widget name.
	 */
	public function get_name() {
		return 'dtr-counter';
	}

	/**
	 * Retrieve widget title.
	 * @access public
	 * @return string Widget title.
	 */
	public function get_title() {
		return esc_html__( 'Counter', 'copr' );
	}

	/**
	 * Retrieve widget icon.
	 * @access public
	 * @return string Widget icon.
	 */
	public function get_icon() {
		return 'eicon-favorite';
	}

	/**
	 * Retrieve the list of categories widget belongs to.
	 * Used to determine where to display the widget in the editor.
	 * @access public
	 * @return array Widget categories.
	 */
	public function get_categories() {
		  return array('dtr-element');

	}
	
	/**
	 * Register the scripts widget depends on.
	 */
	public function __construct( $data = [], $args = null ) {
		parent::__construct( $data, $args );
	  	wp_register_script( 'jquery-numerator', COPR_ELEMENTOR_ADDONS_URL . 'assets/js/jquery-numerator.js', [ 'elementor-frontend' ], '0.2.1', true );
    }
	
	/**
	 * Retrieve the list of scripts the widget depends on.
	 * Used to set scripts dependencies required to run the widget.
	 * @return array Widget scripts dependencies.
	 */
	public function get_script_depends() {
        return [
			'jquery-numerator',
        ];
    }

	/**
	 * Register widget controls.
	 * Adds different input fields to allow the user to change and customize the widget settings.
	 * @access protected
	 */
	protected function register_controls() {
		
		// image control starts
		$this->start_controls_section(
			'section_counter',
			[
				'label'	=> esc_html__( 'Counter', 'copr' ),
			]
		);

		$this->add_control(
			'starting_number',
			[
				'label' 		=> esc_html__( 'Staring Number', 'copr' ),
				'type' 			=> Controls_Manager::TEXT,
				'default' 		=> esc_html__( '1', 'copr' ),
				'placeholder'	=> esc_html__( '1', 'copr' ),
				'label_block' 	=> true,
				'separator' 	=> 'before',
			]
		);
		
		$this->add_control(
			'ending_number',
			[
				'label' 		=> esc_html__( 'Ending Number', 'copr' ),
				'type' 			=> Controls_Manager::TEXT,
				'default' 		=> esc_html__( '100', 'copr' ),
				'placeholder'	=> esc_html__( '100', 'copr' ),
				'label_block' 	=> true,
				'separator' 	=> 'before',
			]
		);
		
		$this->add_control(
			'duration',
			[
				'label' => __( 'Animation Duration', 'copr' ),
				'type' => Controls_Manager::NUMBER,
				'default' => 2000,
				'min' => 100,
				'step' => 100,
				'separator' => 'before',
			]
		);
		
		$this->add_control(
			'text_settings',
			[
				'label' 	=> esc_html__( 'Text', 'copr' ),
				'type' 		=> Controls_Manager::HEADING,
				'separator'	=> 'before',
			]
		);
		
		$this->add_control(
			'heading',
			[
				'label' 		=> esc_html__( '', 'copr' ),
				'type' 			=> Controls_Manager::TEXT,
				'default' 		=> esc_html__( 'Happy Clients', 'copr' ),
				'placeholder'	=> esc_html__( 'Happy Clients', 'copr' ),
				'label_block' 	=> true,
			]
		);
		
		$this->add_responsive_control(
			'heading_top_position',
			[
				'label' => esc_html__( 'Position From Top', 'copr' ),
				'type' => Controls_Manager::SLIDER,
				'range' => [
					'px' => [
						'max' => 300,
					],
				],
				'default' => [
				'size' => '',
				],
				'selectors' => [
					'{{WRAPPER}} .dtr-counter__heading' => 'top: calc({{SIZE}}{{UNIT}})',
				],
			]
		);

		$this->add_control(
			'view',
			[
				'label' 	=> esc_html__( 'View', 'copr' ),
				'type' 		=> Controls_Manager::HIDDEN,
				'default'	=> 'traditional',
			]
		);
		
		$this->end_controls_section();

		// style control starts
		$this->start_controls_section(
			'section_style_content',
			[
				'label'	=> esc_html__( 'Styles', 'copr' ),
				'tab'   => Controls_Manager::TAB_STYLE,
			]
		);
		
		$this->add_control(
			'number_style',
			[
				'label' => esc_html__( 'Number', 'copr' ),
				'type' 	=> Controls_Manager::HEADING,
			]
		);
		
		$this->add_control(
			'number_color',
			[
				'label' 	=> esc_html__( 'Number Color', 'copr' ),
				'default' 	=> '',
				'type' 		=> Controls_Manager::COLOR,
				'selectors'	=> [
					'{{WRAPPER}} .dtr-counter__number'	=> 'color: {{VALUE}};',
				],
			]
		);
		
		$this->add_group_control(
            Group_Control_Typography::get_type(),
            [
                'name' 		=> 'number_typo',
				'label' 	=> esc_html__( 'Typography', 'copr' ),
                'selector'	=> '{{WRAPPER}} .dtr-counter__number',
            ]
        );
		
		// heading
		$this->add_control(
			'heading_style',
			[
				'label' => esc_html__( 'Text', 'copr' ),
				'type' 	=> Controls_Manager::HEADING,
				'separator' => 'before',
			]
		);
		
		$this->add_control(
			'heading_bg_color',
			[
				'label' 	=> esc_html__( 'Background Color', 'copr' ),
				'default' 	=> '',
				'type' 		=> Controls_Manager::COLOR,
				'selectors'	=> [
					'{{WRAPPER}} .dtr-counter__heading'	=> 'background-color: {{VALUE}};',
				],
			]
		);
				
		$this->add_control(
			'heading_color',
			[
				'label' 	=> esc_html__( 'Color', 'copr' ),
				'default' 	=> '',
				'type' 		=> Controls_Manager::COLOR,
				'selectors'	=> [
					'{{WRAPPER}} .dtr-counter__heading'	=> 'color: {{VALUE}};',
				],
			]
		);
		
		$this->add_group_control(
            Group_Control_Typography::get_type(),
            [
                'name' 		=> 'main_heading_typo',
				'label' 	=> esc_html__( 'Typography', 'copr' ),
                'selector'	=> '{{WRAPPER}} .dtr-counter__heading',
            ]
        );

		$this->end_controls_section();
		// style control ends
	}

	/**
	 * Render widget output on the frontend.
	 * Written in PHP and used to generate the final HTML.
	 * @access protected
	 */
	protected function render() {
		$settings = $this->get_settings();
		$this->add_render_attribute( 'counter', [
			'class' => 'dtr-counter__number elementor-counter-number',
			'data-duration' => $settings['duration'],
			'data-to-value' => $settings['ending_number'],
			'data-from-value' => $settings['starting_number'],
		] );
	  	?>
<div class="dtr-counter elementor-element elementor-widget-counter" data-element_type="widget" data-widget_type="counter.default">
	<p <?php echo $this->get_render_attribute_string( 'counter' ); ?>><?php echo esc_html( $settings['starting_number'] ) ?></p>
    <?php if ( $settings['heading'] ) { ?>
    <h6 class="dtr-counter__heading"><?php echo esc_html( $settings['heading'] ) ?></h6>
    <?php } ?>
</div>
<?php
	}

	/**
	 * Render widget output in the editor.
	 * Written as a Backbone JavaScript template and used to generate the live preview.
	 * @access protected
	 */
	protected function content_template() {
		?>
    <div class="dtr-counter elementor-element elementor-widget-counter" data-element_type="widget" data-widget_type="counter.default">
    	<p class="dtr-counter__number elementor-counter-number" data-duration="{{ settings.duration }}" data-to-value="{{ settings.ending_number }}" data-from-value="{{ settings.starting_number }}">
    	{{{ settings.starting_number }}}</p>
        <# if ( settings.heading ) { #>
            <h6 class="dtr-counter__heading">{{{ settings.heading }}}</h6>
        <# } #>
    </div>
<?php
	}
}