<?php
namespace CoprAddons\Widgets;

use Elementor\Widget_Base;
use Elementor\Controls_Manager;
use Elementor\Utils;
use Elementor\Icons_Manager;
use Elementor\Group_Control_Typography;

if ( ! defined( 'ABSPATH' ) ) {
	exit; // Exit if accessed directly.
}

/**
 * Widget
 */
class Copr_Feature extends Widget_Base {

	/**
	 * Retrieve widget name.
	 * @access public
	 * @return string Widget name.
	 */
	public function get_name() {
		return 'dtr-feature';
	}

	/**
	 * Retrieve widget title.
	 * @access public
	 * @return string Widget title.
	 */
	public function get_title() {
		return __( 'Icon Feature', 'copr' );
	}

	/**
	 * Retrieve widget icon.
	 * @access public
	 * @return string Widget icon.
	 */
	public function get_icon() {
		return 'eicon-favorite';
	}
	
	/**
	 * Retrieve the list of categories widget belongs to.
	 * Used to determine where to display the widget in the editor.
	 * @access public
	 * @return array Widget categories.
	 */
	public function get_categories() {
		return array('dtr-element');
	}
	
	/**
	 * Register widget controls.
	 * Adds different input fields to allow the user to change and customize the widget settings.
	 * @access protected
	 */
	protected function register_controls() {
		$this->start_controls_section(
			'section_feature',
			[
				'label' => __( 'Icon Feature', 'copr' ),
			]
		);
		
		$this->add_control(
			'feature_align_style',
			[
				'label' => esc_html__( 'Icon Align', 'copr' ),
				'type' => Controls_Manager::SELECT,
				'default' => 'dtr-feature--icon-align-left',
				'label_block' => true,
				'options' => [
					'dtr-feature--icon-align-left'		=> esc_html__( 'Left', 'copr' ),
					'dtr-feature--icon-align-right' 	=> esc_html__( 'Right', 'copr' ),
					'dtr-feature--icon-align-top'	    => esc_html__( 'Top', 'copr' ),
				],
			]
		);
		
		$this->add_control(
			'feature_vert_align',
			[
				'label' => esc_html__( 'Icon Vertical Align', 'copr' ),
				'type' => Controls_Manager::SELECT,
				'default' => 'dtr-feature--icon-vert-align-top',
				'label_block' => true,
				'options' => [
					'dtr-feature--icon-vert-align-top'		=> esc_html__( 'Top', 'copr' ),
					'dtr-feature--icon-vert-align-center'	=> esc_html__( 'Middle', 'copr' ),
				],
				'condition' => [
					'feature_align_style'	=> [ 'dtr-feature--icon-align-left', 'dtr-feature--icon-align-right' ],
				],
			]
		);
		
		$this->add_control(
			'text_align',
			[
				'label' => esc_html__( 'Text Align', 'copr' ),
				'type' => Controls_Manager::SELECT,
				'default' => 'dtr-feature--text-left',
				'label_block' => true,
				'options' => [
					'dtr-feature--text-left'	=> esc_html__( 'Left', 'copr' ),
					'dtr-feature--text-right' 	=> esc_html__( 'Right', 'copr' ),
					'dtr-feature--text-center'	=> esc_html__( 'Center', 'copr' ),
				],
				'condition' => [
					'feature_align_style'	=> [ 'dtr-feature--icon-align-top' ],
				],
			]
		);
		
		$this->add_control(
			'feature_icon_style',
			[
				'label' => esc_html__( 'Feature Icon Style', 'copr' ),
				'type' => Controls_Manager::SELECT,
				'default' => 'dtr-feature--style-default',
				'label_block' => true,
				'options' => [
					'dtr-feature--style-default'	=> esc_html__( 'Default', 'copr' ),
					'dtr-feature--style-circle' 	=> esc_html__( 'Circle Background', 'copr' ),
					'dtr-feature--style-square'	=> esc_html__( 'Square Background', 'copr' ),
				],
			]
		);
		
		$this->add_control(
			'feature_icon_size_style',
			[
				'label' => esc_html__( 'Icon background Size', 'copr' ),
				'type' => Controls_Manager::SELECT,
				'default' => 'dtr-feature--size-small',
				'label_block' => true,
				'condition' => [
					'feature_icon_style'	=> [ 'dtr-feature--style-circle', 'dtr-feature--style-square' ],
				],
				'options' => [
					'dtr-feature--size-small'	=> esc_html__( 'Small', 'copr' ),
					'dtr-feature--size-large' => esc_html__( 'Large', 'copr' ),
				],
			]
		);
		
		$this->add_control(
			'icon_size',
			[
				'label' => esc_html__( 'Icon Size', 'copr' ),
				'type' => Controls_Manager::SLIDER,
				'separator' => 'before',
				'condition' => [
					'feature_icon_style'	=> [ 'dtr-feature--style-default' ],
				],
				'range' => [
					'px' => [
						'max' => 200,
					],
				],
				'default' => [
				'size' => 32,
				],
				'selectors' => [
					'{{WRAPPER}} .dtr-feature__icon' => 'font-size: {{SIZE}}{{UNIT}}',
				],
			]
		);
		
		$this->add_control(
			'icon_m_top',
			[
				'label' => esc_html__( 'Margin Top to Icon', 'copr' ),
				'type' => Controls_Manager::SLIDER,
				'range' => [
					'px' => [
						'max' => 200,
					],
				],
				'default' => [
				'size' => '',
				],
				'condition' => [
					'feature_icon_style'	=> [ 'dtr-feature--style-default' ],
				],
				'selectors' => [
					'{{WRAPPER}} .dtr-feature__icon' => 'margin-top: {{SIZE}}{{UNIT}}',
				],
			]
		);
		
		$this->add_control(
			'icon_library',
			[
				'label' => esc_html__( 'Icon Library', 'copr' ),
				'type' => Controls_Manager::SELECT,
				'default' => 'dtr-theme-custom-icons',
				'separator' => 'before',
				'label_block' => true,
				'options' => [
					'dtr-font-awesome-icons'	=> esc_html__( 'Font Awesome Library', 'copr' ),
					'dtr-theme-custom-icons' 	=> esc_html__( 'Theme Custom Library', 'copr' ),
				],
			]
		);
		
		$this->add_control(
			'default_icon',
			[
				'label' => esc_html__( 'Font Awesome Library', 'copr' ),
				'type' => Controls_Manager::ICONS,
				'fa4compatibility' => 'icon',
				'default' => [
					'value' => 'fas fa-star',
					'library' => 'fa-solid',
				],
				'label_block' => true,
				'condition' => [
					'icon_library' => [ 'dtr-font-awesome-icons' ],
				],
			]
		);

		// custom icons
		$this->add_control(
			'custom_icon',
			[
				'label' => esc_html__( 'Theme Custom Library', 'copr' ),
				'type' => Controls_Manager::SELECT2,
				'default' => 'icon-star-solid',
				'label_block' => true,
				'condition' => [
					'icon_library'	=> [ 'dtr-theme-custom-icons' ],
				],
				'description' => esc_html__( 'Icon demo file for extra icons is included in help document.', 'copr' ),
				'options' => dtr_icons(),
			]
		);
		
		// heading
		$this->add_control(
			'heading',
			[
				'label' 		=> esc_html__( 'Heading', 'copr' ),
				'type' 			=> Controls_Manager::TEXTAREA,
				'default' 		=> esc_html__( 'Heading Goes Here', 'copr' ),
				'placeholder' 	=> esc_html__( 'Heading Goes Here', 'copr' ),
				'label_block'	=> true,
				'show_label'	=> true,
				'separator' 	=> 'before',
			]
		);
				
		$this->add_control(
			'heading_size',
			[
				'label' 	=> esc_html__( 'Heading - HTML Tag', 'elementor' ),
				'type' 		=> Controls_Manager::SELECT,
				'options'	=> [
					'h1' 	=> 'H1',
					'h2' 	=> 'H2',
					'h3' 	=> 'H3',
					'h4' 	=> 'H4',
					'h5' 	=> 'H5',
					'h6'	=> 'H6',
					'p' 	=> 'p',
				],
				'default' => 'h4',
			]
		);
		
		// subtext
		$this->add_control(
			'subtext',
			[
				'label' 		=> esc_html__( 'Sub Text', 'copr' ),
				'type' 			=> Controls_Manager::TEXTAREA,
				'default' 		=> esc_html__( 'Sub Text Goes Here', 'copr' ),
				'placeholder' 	=> esc_html__( 'Sub Text', 'copr' ),
				'label_block'	=> true,
				'show_label'	=> true,
				'separator' 	=> 'before',
			]
		);
		
		// content
		$this->add_control(
			'feature_content',
			[
				'label' 		=> esc_html__( 'Content', 'copr' ),
				'type' 			=> Controls_Manager::TEXTAREA,
				'default' 		=> '',
				'separator'		=> 'before',
				'placeholder' 	=> esc_html__( 'Your Content', 'copr' ),
				'label_block' 	=> true,
			]
		);
		
		$this->add_control(
			'all_content_m_top',
			[
				'label' => esc_html__( 'Margin Top to Content Section', 'copr' ),
				'type' => Controls_Manager::SLIDER,
				'separator'		=> 'before',
				'range' => [
					'px' => [
						'max' => 200,
					],
				],
				'default' => [
				'size' => '',
				],
				'condition' => [
					'feature_align_style'	=> [ 'dtr-feature--icon-align-top' ],
				],
				'selectors' => [
					'{{WRAPPER}} .dtr-feature--icon-align-top .dtr-feature__content' => 'margin-top: {{SIZE}}{{UNIT}}',
				],
			]
		);

		$this->add_control(
			'view',
			[
				'label' => __( 'View', 'copr' ),
				'type' => Controls_Manager::HIDDEN,
				'default' => 'traditional',
			]
		);

		$this->end_controls_section();
		
		$this->start_controls_section(
			'section_style',
			[
				'label' => __( 'Styles', 'copr' ),
				'tab' => Controls_Manager::TAB_STYLE,
			]
		);
		
		$this->add_control(
			'icon_color',
			[
				'label' => __( 'Icon Color', 'copr' ),
				'type' => Controls_Manager::COLOR,
				'default' => '',
				'selectors' => [
					'{{WRAPPER}} .dtr-feature__icon' => 'color: {{VALUE}};',
				],
			]
		);
		
		$this->add_control(
			'icon_bg_color',
			[
				'label' => __( 'Icon Background Color', 'copr' ),
				'type' => Controls_Manager::COLOR,
				'default' => '',
				'condition' => [
					'feature_icon_style'	=> [ 'dtr-feature--style-circle', 'dtr-feature--style-square' ],
				],
				'selectors' => [
					'{{WRAPPER}} .dtr-feature__icon' => 'background-color: {{VALUE}};',
				],
			]
		);

		$this->add_control(
			'icon_border_color',
			[
				'label' 	=> esc_html__( 'Icon Border Color', 'copr' ),
				'type' 		=> Controls_Manager::COLOR,
				'default' 	=> '',
				'selectors'	=> [
					'{{WRAPPER}} .dtr-feature__icon'	=> 'border-color: {{VALUE}};',
				],
			]
		);
		
		// heading
		$this->add_control(
			'heading_style_control',
			[
				'label' 	=> esc_html__( 'Heading', 'copr' ),
				'type' 		=> Controls_Manager::HEADING,
				'separator'	=> 'before',
			]
		);

		$this->add_control(
			'heading_color',
			[
				'label' 	=> esc_html__( 'Heading', 'copr' ),
				'type' 		=> Controls_Manager::COLOR,
				'default' 	=> '',
				'selectors'	=> [
					'{{WRAPPER}} .dtr-feature__heading'	=> 'color: {{VALUE}};',
				],
			]
		);
		
		$this->add_group_control(
            Group_Control_Typography::get_type(),
            [
                'name' 		=> 'heading_typo',
				'label' 	=> esc_html__( 'Typography', 'copr' ),
                'selector' 	=> '{{WRAPPER}} .dtr-feature__heading',
            ]
        );
		
		// subtext
		$this->add_control(
			'subtext_style_control',
			[
				'label' 	=> esc_html__( 'Subtext', 'copr' ),
				'type' 		=> Controls_Manager::HEADING,
				'separator'	=> 'before',
			]
		);

		$this->add_control(
			'subtext_color',
			[
				'label' 	=> esc_html__( 'Heading', 'copr' ),
				'type' 		=> Controls_Manager::COLOR,
				'default' 	=> '',
				'selectors'	=> [
					'{{WRAPPER}} .dtr-feature__subtext'	=> 'color: {{VALUE}};',
				],
			]
		);
		
		$this->add_group_control(
            Group_Control_Typography::get_type(),
            [
                'name' 		=> 'subtext_typo',
				'label' 	=> esc_html__( 'Typography', 'copr' ),
                'selector' 	=> '{{WRAPPER}} .dtr-feature__subtext',
            ]
        );


		// text
		$this->add_control(
			'text_style_control',
			[
				'label' 	=> esc_html__( 'Text', 'copr' ),
				'type' 		=> Controls_Manager::HEADING,
				'separator'	=> 'before',
			]
		);
		
		$this->add_control(
			'text_color',
			[
				'label' 	=> esc_html__( 'Text', 'copr' ),
				'type' 		=> Controls_Manager::COLOR,
				'default' 	=> '',
				'selectors'	=> [
					'{{WRAPPER}} .dtr-feature__text'	=> 'color: {{VALUE}};',
				],
			]
		);
		
		$this->add_group_control(
            Group_Control_Typography::get_type(),
            [
                'name' 		=> 'text_typo',
				'label' 	=> esc_html__( 'Typography', 'copr' ),
                'selector' 	=> '{{WRAPPER}} .dtr-feature__text',
            ]
        );
		
		$this->end_controls_section();
	}

		/**
	 * Render widget output on the frontend.
	 * Written in PHP and used to generate the final HTML.
	 * @access protected
	 */
	protected function render() {
		$settings = $this->get_settings(); 

		// icon
		if ( ! empty( $settings['custom_icon'] ) ) {
			$this->add_render_attribute( 'custom_icon', 'class', $settings['custom_icon'] );
			$this->add_render_attribute( 'custom_icon', 'aria-hidden', 'true' );
		}
		?>
        <div class="dtr-feature <?php echo esc_attr( $settings['feature_icon_style'] ); ?> <?php echo esc_attr( $settings['feature_vert_align'] ); ?> <?php echo esc_attr( $settings['text_align'] ); ?> <?php echo esc_attr( $settings['feature_align_style'] ); ?> <?php echo esc_attr( $settings['feature_icon_size_style'] ); ?>">
        <div class="dtr-feature__icon">
		 <?php if ( $settings['icon_library'] == 'dtr-theme-custom-icons' && ! empty( $settings['default_icon'] ) ) { ?>
            <i <?php echo $this->get_render_attribute_string( 'custom_icon' ); ?>></i>
        <?php } else { ?>
            <?php Icons_Manager::render_icon( $settings['default_icon'], [ 'aria-hidden' => 'true' ] ); ?>
        <?php } ?>
        </div>
        <?php if ( ! empty( $settings['subtext'] ) || ! empty( $settings['heading'] ) || ! empty( $settings['feature_content'] ) ) { ?>
             <div class="dtr-feature__content">
             <?php if ( ! empty( $settings['subtext'] ) ) { ?>
             <p class="dtr-feature__subtext"><?php echo wp_kses_post( $settings['subtext'] ); ?></p>
             <?php } ?>
             <?php if ( ! empty( $settings['heading'] ) ) { ?>
             <<?php echo esc_attr( $settings['heading_size'] ) ?> class="dtr-feature__heading"><?php echo wp_kses_post( $settings['heading'] ); ?></<?php echo esc_attr( $settings['heading_size'] ) ?>>
             <?php } ?>
             <?php if ( ! empty( $settings['feature_content'] ) ) { ?>
             <div class="dtr-feature__text"><?php echo wp_kses_post( $settings['feature_content'] ) ?></div>
             <?php } ?>
             </div>
        <?php } ?>
        </div>
<?php	}

	/**
	 * Render widget output in the editor.
	 * Written as a Backbone JavaScript template and used to generate the live preview.
	 * @access protected
	 */
	protected function content_template() {
		?>
        <# iconHTML = elementor.helpers.renderIcon( view, settings.default_icon, { 'aria-hidden': true }, 'i' , 'object' ); #>
        <div class="dtr-feature {{ settings.feature_icon_style }} {{ settings.feature_vert_align }} {{ settings.text_align }} {{ settings.feature_align_style }} {{ settings.feature_icon_size_style }}">
            <div class="dtr-feature__icon">
            <# if ( settings.icon_library == 'dtr-theme-custom-icons' ) { #>
                <i class="{{ settings.custom_icon }}"></i> 	
            <# } else {  #>
                {{{ iconHTML.value }}}	
            <#	} #>
            </div>
            <div class="dtr-feature__content">
            <# if ( settings.subtext != '' ) { #>
            <p class="dtr-feature__subtext">{{{ settings.subtext }}}</p>
            <# } #>
            <# if ( settings.heading != '' ) { #>
            <{{ settings.heading_size }} class="dtr-feature__heading"> {{{ settings.heading }}}</{{ settings.heading_size }}>
            <# } #>
            <# if ( settings.feature_content != '' ) { #>
            <div class="dtr-feature__text">{{{ settings.feature_content }}}</div>
            <# } #>
            </div>
        </div> 
		<?php
	}
}