<?php
namespace CoprAddons\Widgets;

use Elementor\Widget_Base;
use Elementor\Controls_Manager;
use Elementor\Utils;
use Elementor\Control_Media;
use Elementor\Group_Control_Typography;
use Elementor\Group_Control_Image_Size;
use Elementor\Icons_Manager;

if ( ! defined( 'ABSPATH' ) ) {
	exit; // Exit if accessed directly.
}

/**
 * Widget
 */
class Copr_Pricing extends Widget_Base {

	/**
	 * Retrieve widget name.
	 * @access public
	 * @return string Widget name.
	 */
	public function get_name() {
		return 'dtr-pricing';
	}

	/**
	 * Retrieve widget title.
	 * @access public
	 * @return string Widget title.
	 */
	public function get_title() {
		return __( 'Pricing', 'copr' );
	}

	/**
	 * Retrieve widget icon.
	 * @access public
	 * @return string Widget icon.
	 */
	public function get_icon() {
		return 'eicon-favorite';
	}

	/**
	 * Retrieve the list of categories widget belongs to.
	 * Used to determine where to display the widget in the editor.
	 * @access public
	 * @return array Widget categories.
	 */
	public function get_categories() {
		return array('dtr-element');
	}
	

	/**
	 * Register widget controls.
	 * Adds different input fields to allow the user to change and customize the widget settings.
	 * @access protected
	 */
	protected function register_controls() {
		// content control starts
		// image
		$this->start_controls_section(
			'section_main_content',
			[
				'label' => __( 'Pricing', 'copr' ),
			]
		);

		$this->add_control(
			'pricing_icon_control',
			[
				'label' 	=> esc_html__( 'Image / Icon Settings', 'copr' ),
				'type' 		=> Controls_Manager::HEADING,
				'separator'	=> 'before',
			]
		);
		
		$this->add_control(
			'pricing_icon_img_type',
			[
				'label' 	=> esc_html__( 'Type', 'copr' ),
				'type'		=> Controls_Manager::SELECT,
				'default'	=> 'dtr-icon-pricing-type-icon',
				'options' 	=> [
					'dtr-icon-pricing-type-img'		=> esc_html__( 'Image', 'copr' ),
					'dtr-icon-pricing-type-icon'	=> esc_html__( 'Icon', 'copr' ),
					'dtr-icon-pricing-type-html'	=> esc_html__( 'Custom HTML', 'copr' ),
				],
			]
		);

		// image
		$this->add_control(
			'pricing_image_control',
			[
				'label' 	=> esc_html__( 'Image', 'copr' ),
				'type' 		=> Controls_Manager::HEADING,
				'condition' => [
					'pricing_icon_img_type'	=> [ 'dtr-icon-pricing-type-img' ],
				],
			]
		);	
			
		$this->add_control(
			'image',
			[
				'label' 	=> esc_html__( 'Choose Image', 'copr' ),
				'type' 		=> Controls_Manager::MEDIA,
				'dynamic' => [
					'active' => true,
				],
				'default'	=> [
					'url'	=> COPR_ELEMENTOR_ADDONS_URL . 'assets/img/img-circle-100x100.png',
				],
				'condition'	=> [
					'pricing_icon_img_type'	=> [ 'dtr-icon-pricing-type-img' ],
				],
			]
		);
		
		$this->add_group_control(
			Group_Control_Image_Size::get_type(),
			[
				'name' 		=> 'thumbnail',
				'default' 	=> 'large',
				'separator'	=> 'none',
				'condition' => [
					'pricing_icon_img_type'	=> [ 'dtr-icon-pricing-type-img' ],
				],
			]
		);

		// custom icon
		$this->add_control(
			'pricing_icon_img_html',
			[
				'label' => __( 'Custom HTML', 'copr' ),
				'type' => Controls_Manager::TEXTAREA,
				'default' => '',
				'label_block' => true,
				'condition' => [
					'pricing_icon_img_type'	=> [ 'dtr-icon-pricing-type-html' ],
				],
			]
		);
		
		// icon
		$this->add_control(
			'pricing_icon',
			[
				'label' => __( 'Icon', 'elementor' ),
				'type' => Controls_Manager::ICONS,
				'fa4compatibility' => 'icon',
				'label_block'		=> true,
				'condition'	=> [
					'pricing_icon_img_type'			=> [ 'dtr-icon-pricing-type-icon' ],
				],
				'default' => [
					'value' => 'fas fa-star',
					'library' => 'fa-solid',
				],
			]
		);
		
		$this->add_control(
			'icon_animation',
			[
				'label' 	=> esc_html__( 'Circle Icon Rotate', 'copr' ),
				'type' 		=> Controls_Manager::SELECT,
				'default' 	=> 'dtr-pricing--animation',
				'separator' => 'before',
				'options'	=> [
					'dtr-pricing--animation' => esc_html__( 'Rotate', 'copr' ),
					''	=> esc_html__( 'None', 'copr' ),
				],
			]
		);
				
	    // pricing_tagline
		$this->add_control(
			'pricing_tagline',
			[
				'label' => __( 'Tagline', 'copr' ),
				'type' => Controls_Manager::TEXT,
				'default' => __( 'Your Tagline', 'copr' ),
				'label_block' => true,
				'separator'	=> 'before',
			]
		);
		
		// pricing_title
		$this->add_control(
			'pricing_title',
			[
				'label' => __( 'Heading', 'copr' ),
				'type' => Controls_Manager::TEXT,
				'default' => __( 'Premium Plan', 'copr' ),
				'separator'	=> 'before',
				'label_block' => true,
			]
		);

		// pricing_price
		$this->add_control(
			'pricing_currency',
			[
				'label' => __( 'Currency', 'copr' ),
				'type' => Controls_Manager::TEXT,
				'default' => __( '$', 'copr' ),
				'label_block' => true,
			]
		);
		
		$this->add_control(
			'pricing_price',
			[
				'label' => __( 'Price', 'copr' ),
				'type' => Controls_Manager::TEXT,
				'default' => __( '199', 'copr' ),
				'label_block' => true,
			]
		);
		
		// description
		$this->add_control(
			'pricing_description',
			[
				'name' => 'tab_content',
				'label' => __( 'Content', 'copr' ),
				'type' => Controls_Manager::WYSIWYG,
				'default' => __( 'Plan intro goes here', 'copr' ),
				'show_label' => true,
			]
		);
		// button
		$this->add_control(
			'link_text',
			[
				'label' => __( 'Button Text', 'copr' ),
				'type' => Controls_Manager::TEXT,
				'default' => __( 'Buy Now', 'copr' ),
				'description' => __('Leave blank if need to hide button.', 'copr'),
				'placeholder' => __( 'Your Button Text', 'copr' ),
				'label_block' => true,
				'separator' => 'before',
			]
		);
		
		$this->add_control(
			'link',
			[
				'label' 		=> esc_html__( 'Link', 'copr' ),
				'type' 			=> Controls_Manager::URL,
				'placeholder'	=> 'http://your-link.com',
				'default'	=> [
					'url'	=> '#',
				],
			]
		);

		$this->add_control(
			'view',
			[
				'label' => __( 'View', 'copr' ),
				'type' => Controls_Manager::HIDDEN,
				'default' => 'traditional',
			]
		);
		$this->end_controls_section();
		// content control ends
		
		// style control starts
		$this->start_controls_section(
			'section_style_content',
			[
				'label' => __( 'Styles', 'copr' ),
				'tab'   => Controls_Manager::TAB_STYLE,
			]
		);
		
		$this->add_control(
			'preset_color_scheme',
			[
				'label' 	=> esc_html__( 'Preset Color Scheme', 'copr' ),
				'type'		=> Controls_Manager::SELECT,
				'default'	=> '',
				'options' 	=> [
					'dtr-pricing--clr-scheme3'	=> esc_html__( 'Primary', 'copr' ),
					'dtr-pricing--clr-scheme2'	=> esc_html__( 'Secondary', 'copr' ),
					''							=> esc_html__( 'Secondary Light', 'copr' ),
				],
			]
		);
		
		// box
		$this->add_control(
			'pricing_box_style_control',
			[
				'label' => __( 'Pricing box', 'copr' ),
				'type' => Controls_Manager::HEADING,
				'separator' => 'before',
			]
		);
		
		$this->add_control(
			'pricing_box_bg',
			[
				'label' => __( 'Background Color', 'copr' ),
				'default' => '',
				'type' => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .dtr-pricing' => 'background-color: {{VALUE}};',
				],
			]
		);
		
		$this->add_control(
			'pricing_box_border',
			[
				'label' => __( 'Border Color', 'copr' ),
				'default' => '',
				'type' => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .dtr-pricing' => 'border-color: {{VALUE}};',
				],
			]
		);
		
		$this->add_control(
			'pricing_compiled_color',
			[
				'label' => __( 'Pricing Base Text Color', 'copr' ),
				'type' => Controls_Manager::COLOR,
				'default' => '',
				'separator' => 'before',
				'selectors' => [
					'{{WRAPPER}} .dtr-pricing' => 'color: {{VALUE}};',
				],
			]
		);
		
		$this->add_control(
			'pricing_icon_wrapper_color',
			[
				'label' => __( 'Icon Wrapping Image Color', 'copr' ),
				'default' => '',
				'type' => Controls_Manager::COLOR,
				'separator' => 'before',
				'selectors' => [
					'{{WRAPPER}} .dtr-pricing__icon-wrapper::before' => 'color: {{VALUE}};',
				],
			]
		);
		
		$this->add_control(
			'pricing_icon_color',
			[
				'label' => __( 'Icon Color', 'copr' ),
				'default' => '',
				'type' => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .dtr-pricing__icon' => 'color: {{VALUE}};',
				],
			]
		);

		// tagline
		$this->add_control(
			'tagline_style_control',
			[
				'label' => __( 'Tagline', 'copr' ),
				'type' => Controls_Manager::HEADING,
				'separator' => 'before',
			]
		);

		$this->add_control(
			'pricing_tagline_color',
			[
				'label' => __( 'Color', 'copr' ),
				'type' => Controls_Manager::COLOR,
				'default' => '',
				'selectors' => [
					'{{WRAPPER}} .dtr-pricing__tagline' => 'color: {{VALUE}};',
				],
			]
		);
		
		$this->add_group_control(
            Group_Control_Typography::get_type(),
            [
                'name' 		=> 'pricing_tagline_typo',
				'label' 	=> esc_html__( 'Typography', 'copr' ),
                'selector' 	=> '{{WRAPPER}} .dtr-pricing__tagline',
            ]
        );
		
		// title
		$this->add_control(
			'title_style_control',
			[
				'label' => __( 'Heading', 'copr' ),
				'type' => Controls_Manager::HEADING,
				'separator' => 'before',
			]
		);
		$this->add_control(
			'pricing_title_color',
			[
				'label' => __( 'Color', 'copr' ),
				'type' => Controls_Manager::COLOR,
				'default' => '',
				'selectors' => [
					'{{WRAPPER}} .dtr-pricing__heading' => 'color: {{VALUE}};',
				],
			]
		);
		
		$this->add_group_control(
            Group_Control_Typography::get_type(),
            [
                'name' 		=> 'pricing_title_typo',
				'label' 	=> esc_html__( 'Typography', 'copr' ),
                'selector' 	=> '{{WRAPPER}} .dtr-pricing__heading',
            ]
        );
		
		// price
		$this->add_control(
			'price_style_control',
			[
				'label' => __( 'Price', 'copr' ),
				'type' => Controls_Manager::HEADING,
				'separator' => 'before',
			]
		);

		$this->add_control(
			'pricing_price_color',
			[
				'label' => __( 'Color', 'copr' ),
				'type' => Controls_Manager::COLOR,
				'default' => '',
				'selectors' => [
					'{{WRAPPER}} .dtr-pricing__price' => 'color: {{VALUE}};',
				],
			]
		);
		
		$this->add_group_control(
            Group_Control_Typography::get_type(),
            [
                'name' 		=> 'pricing_price_typo',
				'label' 	=> esc_html__( 'Typography', 'copr' ),
                'selector' 	=> '{{WRAPPER}} .dtr-pricing__price',
            ]
        );
		
		$this->add_group_control(
            Group_Control_Typography::get_type(),
            [
                'name' 		=> 'pricing_currency_typo',
				'label' 	=> esc_html__( 'Currency Typography', 'copr' ),
                'selector' 	=> '{{WRAPPER}} .dtr-pricing__currency',
            ]
        );

		// description
		$this->add_control(
			'description_style_control',
			[
				'label' => __( 'Description', 'copr' ),
				'type' => Controls_Manager::HEADING,
				'separator' => 'before',
			]
		);
		$this->add_control(
			'description_color',
			[
				'label' => __( 'Color', 'copr' ),
				'type' => Controls_Manager::COLOR,
				'default' => '',
				'selectors' => [
					'{{WRAPPER}} .dtr-pricing__description' => 'color: {{VALUE}};',
				],
			]
		);
		
		$this->add_control(
			'description_list_border',
			[
				'label' => __( 'List Icon Color', 'copr' ),
				'type' => Controls_Manager::COLOR,
				'default' => '',
				'selectors' => [
					'{{WRAPPER}} .dtr-pricing__description li::before' => 'color: {{VALUE}};',
				],
			]
		);
		
		$this->add_group_control(
            Group_Control_Typography::get_type(),
            [
                'name' 		=> 'pricing_description_typo',
				'label' 	=> esc_html__( 'Typography', 'copr' ),
                'selector' 	=> '{{WRAPPER}} .dtr-pricing__description',
            ]
        );
		
		// button
		$this->add_control(
			'button_style_control',
			[
				'label' => __( 'Button', 'copr' ),
				'type' => Controls_Manager::HEADING,
				'separator' => 'before',
			]
		);
		
		$this->add_control(
			'pricing_button_bg',
			[
				'label' => __( 'Background Color', 'copr' ),
				'type' => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .dtr-btn' => 'background-color: {{VALUE}};',
				],
			]
		);
		
		$this->add_control(
			'pricing_button_border_color',
			[
				'label' => __( 'Border Color', 'copr' ),
				'type' => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .dtr-btn' => 'border-color: {{VALUE}};',
				],
			]
		);
			
		$this->add_control(
			'pricing_button_color',
			[
				'label' => __( 'Text Color', 'copr' ),
				'type' => Controls_Manager::COLOR,
				'default' => '',
				'selectors' => [
					'{{WRAPPER}} .dtr-btn' => 'color: {{VALUE}};',
				],
			]
		);
		
		$this->add_control(
			'pricing_button_hover_bg',
			[
				'label' => __( 'Hover: Background Color', 'copr' ),
				'type' => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .dtr-btn:hover' => 'background-color: {{VALUE}};',
				],
			]
		);
		
		$this->add_control(
			'pricing_button_hover_border_color',
			[
				'label' => __( 'Hover: Border Color', 'copr' ),
				'type' => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .dtr-btn:hover' => 'border-color: {{VALUE}};',
				],
			]
		);
			
		$this->add_control(
			'pricing_button_hover_color',
			[
				'label' => __( 'Hover: Text Color', 'copr' ),
				'type' => Controls_Manager::COLOR,
				'default' => '',
				'selectors' => [
					'{{WRAPPER}} .dtr-btn:hover' => 'color: {{VALUE}};',
				],
			]
		);
		
		$this->end_controls_section();
		// style control ends
	}

	/**
	 * Render widget output on the frontend.
	 * Written in PHP and used to generate the final HTML.
	 * @access protected
	 */
	protected function render() {
		$settings = $this->get_settings(); 
		
		// button
		if ( ! empty( $settings['link']['url'] ) ) {
			$this->add_render_attribute( 'button', 'href', $settings['link']['url'] );
			$this->add_render_attribute( 'button', 'class', 'dtr-btn dtr-pricing__btn' );
			if ( $settings['link']['is_external'] ) {
				$this->add_render_attribute( 'button', 'target', '_blank' );
			}
			if ( $settings['link']['nofollow'] ) {
				$this->add_render_attribute( 'button', 'rel', 'nofollow' );
			}
		}
		$this->add_render_attribute( 'button', 'role', 'button' );
		?>
		<div class="dtr-pricing <?php echo esc_attr( $settings['icon_animation'] ) ?> <?php echo esc_attr( $settings['preset_color_scheme'] ) ?>">
            <?php if ( ! empty( $settings['pricing_tagline'] ) ) { ?>
            <div class="dtr-pricing__tagline"><?php echo esc_html( $settings['pricing_tagline'] ); ?></div>
		    <?php } ?>
        	<div class="dtr-pricing__icon-wrapper">
            	<span class="dtr-pricing__icon">
				<?php	if ( $settings['pricing_icon_img_type'] == 'dtr-icon-pricing-type-icon' ) { ?>
					<?php Icons_Manager::render_icon( $settings['pricing_icon'], [ 'aria-hidden' => 'true' ] ); ?>
				<?php } elseif ( $settings['pricing_icon_img_type'] == 'dtr-icon-pricing-type-img' && ! empty( $settings['image']['url'] ) ) {
						$this->add_render_attribute( 'image', 'src', $settings['image']['url'] );
                    	$this->add_render_attribute( 'image', 'alt', Control_Media::get_image_alt( $settings['image'] ) );
                    	$this->add_render_attribute( 'image', 'title', Control_Media::get_image_title( $settings['image'] ) );
                    	$image_html = Group_Control_Image_Size::get_attachment_image_html( $settings, 'thumbnail', 'image' );
                    	echo $image_html; ?>
				<?php } else { 
						echo wp_kses_post( $settings['pricing_icon_img_html'] );
				} ?>
                </span>
			</div>
			<?php if ( ! empty( $settings['pricing_title'] ) ) { ?>
            <h3 class="dtr-pricing__heading"><?php echo wp_kses_post( $settings['pricing_title'] ); ?></h3>
            <?php } ?>
            <?php if ( ! empty( $settings['pricing_description'] ) ) { ?>
            <div class="dtr-pricing__description"><?php echo wp_kses_post( $settings['pricing_description'] ) ?></div>
            <?php } ?>
			<?php if ( ! empty( $settings['pricing_price'] ) ) { ?>
            <p class="dtr-pricing__price"><span class="dtr-pricing__currency"><?php echo esc_html( $settings['pricing_currency'] ); ?></span><?php echo esc_html( $settings['pricing_price'] ); ?></p>
            <?php } ?>
			<?php if ( ! empty( $settings['link_text'] ) ) { ?>
            <a <?php echo $this->get_render_attribute_string( 'button' ); ?>><span class="dtr-btn__text"><?php echo esc_html( $settings['link_text'] ); ?></span></a>
            <?php } ?>
		</div>
<?php	}

	/**
	 * Render widget output in the editor.
	 * Written as a Backbone JavaScript template and used to generate the live preview.
	 * @access protected
	 */
	protected function content_template() {
		?>
		<div class="dtr-pricing {{{settings.icon_animation }}} {{{settings.preset_color_scheme }}}">
        	<# if ( settings.pricing_tagline ) { #>
            <div class="dtr-pricing__tagline">{{{ settings.pricing_tagline }}}</div>
            <# } #>
            
            <div class="dtr-pricing__icon-wrapper">
               <# if( settings.pricing_icon_img_type == 'dtr-icon-pricing-type-icon' ) {
               		iconHTML = elementor.helpers.renderIcon( view, settings.pricing_icon, { 'aria-hidden': true }, 'i' , 'object' ); #>
                    <span class="dtr-pricing__icon">{{{ iconHTML.value }}}</span>
               <# } else if( settings.pricing_icon_img_type == 'dtr-icon-pricing-type-img' )  {
                     var image = {
                    id: settings.image.id,
                    url: settings.image.url,
                    size: settings.thumbnail_size,
                    dimension: settings.thumbnail_custom_dimension,
                    model: view.getEditModel()
                    };
                    var image_url = elementor.imagesManager.getImageUrl( image );  #>
					<span class="dtr-pricing__icon"><img src="{{ image_url }}"/> </span>
                <# } else { #>	
                {{{ settings.pricing_icon_img_html }}}
                 <# } #>	
            </div>
            
            <# if ( settings.pricing_title ) { #>
                <h4 class="dtr-pricing__heading">{{{ settings.pricing_title }}}</h4>
            <# } #>

            <# if ( settings.pricing_description ) { #>
            <div class="dtr-pricing__description">{{{ settings.pricing_description }}}</div>
            <# } #>
                        
            <# if ( settings.pricing_price ) { #>
             <p class="dtr-pricing__price"><span class="dtr-pricing__currency">{{{ settings.pricing_currency }}}</span>{{{ settings.pricing_price }}}</p>
            <# } #>

            <# if ( settings.link_text ) { #>
                <a class="dtr-btn dtr-pricing__btn" href="{{ settings.link.url }}" role="button"><span class="dtr-btn__text">{{{ settings.link_text }}}</span></a> 
            <# } #> 
		</div>
		<?php
	}
}