<?php
namespace CoprAddons\Widgets;
use Elementor\Widget_Base;
use Elementor\Controls_Manager;
use Elementor\Utils;
use Elementor\Control_Media;
use Elementor\Group_Control_Typography;
use Elementor\Group_Control_Image_Size;

if ( ! defined( 'ABSPATH' ) ) {
	exit; // Exit if accessed directly.
}
/**
 * Rotating Image Widget
 */
class Copr_Rotating_Image extends Widget_Base {

	/**
	 * Retrieve widget name.
	 * @access public
	 * @return string Widget name.
	 */
	public function get_name() {
		return 'dtr-rotating-image';
	}

	/**
	 * Retrieve widget title.
	 * @access public
	 * @return string Widget title.
	 */
	public function get_title() {
		return esc_html__( 'Rotating Image', 'copr' );
	}

	/**
	 * Retrieve widget icon.
	 * @access public
	 * @return string Widget icon.
	 */
	public function get_icon() {
		return 'eicon-favorite';
	}

	/**
	 * Retrieve the list of categories widget belongs to.
	 * Used to determine where to display the widget in the editor.
	 * @access public
	 * @return array Widget categories.
	 */
	public function get_categories() {
		  return array('dtr-element');

	}

	/**
	 * Register widget controls.
	 * Adds different input fields to allow the user to change and customize the widget settings.
	 * @access protected
	 */
	protected function register_controls() {
		
		// image control starts
		$this->start_controls_section(
			'section_main_image',
			[
				'label'	=> esc_html__( 'Rotating Image', 'copr' ),
			]
		);

		$this->add_control(
			'main_image_control',
			[
				'label' => esc_html__( 'Image', 'copr' ),
				'type' => Controls_Manager::HEADING,
				'separator' => 'before',
			]
		);		
		$this->add_control(
			'image',
			[
				'label' 	=> esc_html__( 'Choose Image', 'copr' ),
				'type' 		=> Controls_Manager::MEDIA,
				'default'	=> [
					'url'	=> COPR_ELEMENTOR_ADDONS_URL . 'assets/img/img-circle-100x100.png',
				],
			]
		);
		
		$this->add_group_control(
			Group_Control_Image_Size::get_type(),
			[
				'name' 		=> 'thumbnail',
				'default' 	=> 'full',
				'separator'	=> 'none',
			]
		);
		
		$this->add_control(
			'rotation_duration',
			[
				'label' => esc_html__( 'Rotation Speed', 'copr' ),
				'type' => Controls_Manager::NUMBER,
				'default' => '',
				'min' => 0.1,
				'step' => 0.1,
				'separator' => 'before',
				'description' => esc_html__( 'It will be in seconds. Give it as numbers.', 'copr' ),
			]
		);

		$this->add_control(
			'view',
			[
				'label' 	=> esc_html__( 'View', 'copr' ),
				'type' 		=> Controls_Manager::HIDDEN,
				'default'	=> 'traditional',
			]
		);
		
		$this->end_controls_section();
		// end main control section
	}

	/**
	 * Render widget output on the frontend.
	 * Written in PHP and used to generate the final HTML.
	 * @access protected
	 */
	protected function render() {
		$settings = $this->get_settings();
	  	?>
        <?php if ( ! empty( $settings['rotation_duration'] ) ) { ?>
        <div class="dtr-rotating-img" style="animation-duration:<?php echo esc_attr( $settings['rotation_duration'] ) ?>">
        <?php } else { ?>
		<div class="dtr-rotating-img">	
		<?php } ?>
                <?php
                $this->add_render_attribute( 'image', 'src', $settings['image']['url'] );
                $this->add_render_attribute( 'image', 'alt', Control_Media::get_image_alt( $settings['image'] ) );
                $this->add_render_attribute( 'image', 'title', Control_Media::get_image_title( $settings['image'] ) );
                $image_html = Group_Control_Image_Size::get_attachment_image_html( $settings, 'thumbnail', 'image' ); ?>
                <?php echo $image_html ?> 
        </div>
<?php
	}

	/**
	 * Render widget output in the editor.
	 * Written as a Backbone JavaScript template and used to generate the live preview.
	 * @access protected
	 */
	protected function content_template() {
		?>
<div class="dtr-rotating-img" style="animation-duration:{{ settings.rotation_duration }}s">
	<#	if ( settings.image.url ) { #>
        <# var image = {
        id: settings.image.id,
        url: settings.image.url,
        size: settings.thumbnail_size,
        dimension: settings.thumbnail_custom_dimension,
        model: view.getEditModel() };
        var image_url = elementor.imagesManager.getImageUrl( image );  #><img src="{{ image_url }}"/>
    <# } #>
</div>
<?php
	}
}