<?php
namespace CoprAddons\Widgets;

use Elementor\Widget_Base;
use Elementor\Controls_Manager;
use Elementor\Utils;
use Elementor\Group_Control_Typography;
use Elementor\Control_Media;
use Elementor\Group_Control_Image_Size;
use Elementor\Icons_Manager;

if ( ! defined( 'ABSPATH' ) ) {
	exit; // Exit if accessed directly.
}

/**
 * Widget
 */
class Copr_Servicebox extends Widget_Base {

	/**
	 * Retrieve widget name.
	 * @access public
	 * @return string Widget name.
	 */
	public function get_name() {
		return 'dtr-servicebox';
	}

	/**
	 * Retrieve widget title.
	 * @access public
	 * @return string Widget title.
	 */
	public function get_title() {
		return esc_html__( 'Service Box', 'copr' );
	}

	/**
	 * Retrieve widget icon.
	 * @access public
	 * @return string Widget icon.
	 */
	public function get_icon() {
		return 'eicon-favorite';
	}

	/**
	 * Retrieve the list of categories widget belongs to.
	 * Used to determine where to display the widget in the editor.
	 * @access public
	 * @return array Widget categories.
	 */
	public function get_categories() {
		return array('dtr-element');
	}
	

	/**
	 * Register widget controls.
	 * Adds different input fields to allow the user to change and customize the widget settings.
	 * @access protected
	 */
	protected function register_controls() {
	
		// content control starts
		$this->start_controls_section(
			'section_servicebox_content',
			[
				'label'	=> esc_html__( 'Service Box', 'copr' ),
			]
		);
		
		$this->add_responsive_control(
			'box_height',
			[
				'label' => esc_html__( 'Box Minimum Height', 'copr' ),
				'type' => Controls_Manager::SLIDER,
				'range' => [
					'px' => [
						'max' => 1000,
					],
				],
				'default' => [
				'size' => '300',
				],
				'selectors' => [
					'{{WRAPPER}} .dtr-servicebox' => 'min-height: calc({{SIZE}}{{UNIT}})',
				],
			]
		);
		
		$this->add_control(
			'servicebox_icon_control',
			[
				'label' 	=> esc_html__( 'Image / Icon Settings', 'copr' ),
				'type' 		=> Controls_Manager::HEADING,
				'separator'	=> 'before',
			]
		);
		
		$this->add_control(
			'servicebox_icon_type',
			[
				'label' 	=> esc_html__( 'Type', 'copr' ),
				'type'		=> Controls_Manager::SELECT,
				'default'	=> 'dtr-icon-type-theme-icon',
				'options' 	=> [
					'dtr-icon-type-img'			=> esc_html__( 'Image', 'copr' ),
					'dtr-icon-type-icon'		=> esc_html__( 'Icon', 'copr' ),
					'dtr-icon-type-theme-icon'	=> esc_html__( 'Theme Icon', 'copr' ),
					'dtr-icon-type-html'	   	=> esc_html__( 'Custom HTML', 'copr' ),
				],
			]
		);

		// image
		$this->add_control(
			'servicebox_icon_type_image_control',
			[
				'label' 	=> esc_html__( 'Image As Icon', 'copr' ),
				'type' 		=> Controls_Manager::HEADING,
				'condition' => [
					'servicebox_icon_type'	=> [ 'dtr-icon-type-img' ],
				],
			]
		);	
			
		$this->add_control(
			'icon_image',
			[
				'label' 	=> esc_html__( 'Choose Image', 'copr' ),
				'type' 		=> Controls_Manager::MEDIA,
				'dynamic' => [
					'active' => true,
				],
				'default'	=> [
					'url'	=> COPR_ELEMENTOR_ADDONS_URL . 'assets/img/img-circle-100x100.png',
				],
				'condition'	=> [
					'servicebox_icon_type'	=> [ 'dtr-icon-type-img' ],
				],
			]
		);
		
		$this->add_group_control(
			Group_Control_Image_Size::get_type(),
			[
				'name' => 'icon_thumbnail',
				'default' => 'full',
				'separator' => 'none',
				'condition' => [
					'servicebox_icon_type'	=> [ 'dtr-icon-type-img' ],
				],
			]
		);
		
		// default icons
		$this->add_control(
			'default_icon',
			[
				'label' => esc_html__( 'Font Awesome Library', 'copr' ),
				'type' => Controls_Manager::ICONS,
				'fa4compatibility' => 'icon',
				'default' => [
					'value' => 'fas fa-star',
					'library' => 'fa-solid',
				],
				'label_block' => true,
				'condition'	=> [
					'servicebox_icon_type' => [ 'dtr-icon-type-icon' ],
				],
			]
		);

		// custom icons
		$this->add_control(
			'custom_icon',
			[
				'label' => esc_html__( 'Theme Custom Library', 'copr' ),
				'type' => Controls_Manager::SELECT2,
				'default' => 'icon-image-solid',
				'label_block' => true,
				'condition'	=> [
					'servicebox_icon_type' => [ 'dtr-icon-type-theme-icon' ],
				],
				'description' => esc_html__( 'Icon demo file for extra icons is included in help document.', 'copr' ),
				'options' => dtr_icons(),
			]
		);
		
		// custom html
		$this->add_control(
			'servicebox_icon_type_html',
			[
				'label' => __( 'Custom HTML', 'copr' ),
				'type' => Controls_Manager::TEXTAREA,
				'default' => '',
				'label_block' => true,
				'condition' => [
					'servicebox_icon_type'	=> [ 'dtr-icon-type-html' ],
				],
			]
		);

		// heading
		$this->add_control(
			'servicebox_heading',
			[
				'label' 		=> esc_html__( 'Bottom Heading', 'copr' ),
				'type' 			=> Controls_Manager::TEXT,
				'default' 		=> esc_html__( 'Bottom Heading', 'copr' ),
				'placeholder' 	=> esc_html__( 'Your Heading', 'copr' ),
				'label_block' 	=> true,
				'separator'	 	=> 'before',
			]
		);
		
		$this->add_control(
			'heading_size',
			[
				'label' 	=> esc_html__( 'Heading / On Hover heading - HTML Tag', 'elementor' ),
				'type' 		=> Controls_Manager::SELECT,
				'options'	=> [
					'h1' 	=> 'H1',
					'h2' 	=> 'H2',
					'h3' 	=> 'H3',
					'h4' 	=> 'H4',
					'h5' 	=> 'H5',
					'h6'	=> 'H6',
					'p' 	=> 'p',
				],
				'default' => 'h4',
			]
		);
		
		// heading
		$this->add_control(
			'servicebox_subheading',
			[
				'label' 		=> esc_html__( 'On Hover: Heading', 'copr' ),
				'type' 			=> Controls_Manager::TEXT,
				'default' 		=> esc_html__( 'Inspire', 'copr' ),
				'placeholder' 	=> esc_html__( 'Your SubHeading', 'copr' ),
				'label_block' 	=> true,
				'separator'	 	=> 'before',
			]
		);
		
		// image
		$this->add_control(
			'servicebox_image_control',
			[
				'label' => esc_html__( 'Box Corner Image', 'copr' ),
				'type' => Controls_Manager::HEADING,
				'separator' => 'before',
			]
		);	
			
		$this->add_control(
			'image',
			[
				'label' 	=> esc_html__( 'Choose Image', 'copr' ),
				'type' 		=> Controls_Manager::MEDIA,
				'default'	=> [
					'url'	=> COPR_ELEMENTOR_ADDONS_URL . 'assets/img/img-circle-100x100.png',
				],
			]
		);
		
		$this->add_group_control(
			Group_Control_Image_Size::get_type(),
			[
				'name' 		=> 'thumbnail',
				'default' 	=> 'full',
				'separator'	=> 'none',
			]
		);
		
		// content
		$this->add_control(
			'servicebox_content',
			[
				'label' 		=> esc_html__( 'On Hover: Content', 'copr' ),
				'type' 			=> Controls_Manager::WYSIWYG,
				'default' 		=> esc_html__( 'Lorem ipsum dolor sit amet consectetur adipiscing labore et dolore magna aliqua. ', 'copr' ),
				'separator'		=> 'before',
				'placeholder' 	=> esc_html__( 'Your Content', 'copr' ),
				'label_block' 	=> true,
			]
		);

		$this->add_control(
			'view',
			[
				'label' 	=> esc_html__( 'View', 'copr' ),
				'type' 		=> Controls_Manager::HIDDEN,
				'default'	=> 'traditional',
			]
		);
		
		$this->end_controls_section();
		// content control ends

		// style control starts
		$this->start_controls_section(
			'section_servicebox_style',
			[
				'label' => esc_html__( 'Styles', 'copr' ),
				'tab'   => Controls_Manager::TAB_STYLE,
			]
		);
		
		$this->add_control(
			'preset_color_scheme',
			[
				'label' 	=> esc_html__( 'Preset Color Scheme', 'copr' ),
				'type'		=> Controls_Manager::SELECT,
				'default'	=> '',
				'options' 	=> [
					'dtr-servicebox--clr-scheme3'	=> esc_html__( 'Primary', 'copr' ),
					'dtr-servicebox--clr-scheme2'	=> esc_html__( 'Secondary', 'copr' ),
					''								=> esc_html__( 'Secondary Light', 'copr' ),
				],
			]
		);
		
		// background image
		$this->add_control(
			'bg_control',
			[
				'label' 	=> esc_html__( 'Background', 'copr' ),
				'type' 		=> Controls_Manager::HEADING,
				'separator'	=> 'before',
			]
		);		
		
		$this->add_responsive_control(
			'bg_color',
			[
				'label' 	=> esc_html__( 'Background Color', 'copr' ),
				'type' 		=> Controls_Manager::COLOR,
				'default' 	=> '',
				'selectors'	=> [
					'{{WRAPPER}} .dtr-servicebox'	=> 'background-color: {{VALUE}};',
				],
			]
		);

		$this->add_control(
			'hover_bg_color',
			[
				'label' 	=> esc_html__( 'On Hover: Background Color', 'copr' ),
				'type' 		=> Controls_Manager::COLOR,
				'default' 	=> '',
				'selectors'	=> [
					'{{WRAPPER}} .dtr-servicebox:hover::before'	=> 'background-color: {{VALUE}};',
				],
			]
		);	
		
		// icon
		$this->add_control(
			'icon_control',
			[
				'label' 	=> esc_html__( 'Top Icon', 'copr' ),
				'type' 		=> Controls_Manager::HEADING,
				'separator'	=> 'before',
			]
		);		
		
		$this->add_responsive_control(
			'icon_color',
			[
				'label' 	=> esc_html__( 'Color', 'copr' ),
				'type' 		=> Controls_Manager::COLOR,
				'default' 	=> '',
				'selectors'	=> [
					'{{WRAPPER}} .dtr-servicebox__icon'	=> 'color: {{VALUE}};',
				],
			]
		);
		
		$this->add_responsive_control(
			'icon_bg_color',
			[
				'label' 	=> esc_html__( 'Background Color', 'copr' ),
				'type' 		=> Controls_Manager::COLOR,
				'default' 	=> '',
				'selectors'	=> [
					'{{WRAPPER}} .dtr-servicebox__icon-wrapper'	=> 'background-color: {{VALUE}};',
				],
			]
		);
		
		$this->add_responsive_control(
			'icon_hover_color',
			[
				'label' 	=> esc_html__( 'On Box Hover - Color', 'copr' ),
				'type' 		=> Controls_Manager::COLOR,
				'default' 	=> '',
				'selectors'	=> [
					'{{WRAPPER}} .dtr-servicebox:hover .dtr-servicebox__icon'	=> 'color: {{VALUE}};',
				],
			]
		);
		
		$this->add_responsive_control(
			'icon_hover_bg_color',
			[
				'label' 	=> esc_html__( 'On Box Hover -  Background Color', 'copr' ),
				'type' 		=> Controls_Manager::COLOR,
				'default' 	=> '',
				'selectors'	=> [
					'{{WRAPPER}} .dtr-servicebox:hover .dtr-servicebox__icon-wrapper'	=> 'background-color: {{VALUE}};',
				],
			]
		);
		
		// Color
		$this->add_control(
			'heading_style_control',
			[
				'label' 	=> esc_html__( 'Heading / Content ', 'copr' ),
				'type' 		=> Controls_Manager::HEADING,
				'separator'	=> 'before',
			]
		);
		
		$this->add_control(
			'heading_color',
			[
				'label' 	=> esc_html__( 'Heading Color', 'copr' ),
				'type' 		=> Controls_Manager::COLOR,
				'default' 	=> '',
				'selectors'	=> [
					'{{WRAPPER}} .dtr-servicebox__title'	=> 'color: {{VALUE}};',
				],
			]
		);
		
		$this->add_control(
			'hover_heading_color',
			[
				'label' 	=> esc_html__( ' On Hover heading / Content Color', 'copr' ),
				'type' 		=> Controls_Manager::COLOR,
				'default' 	=> '',
				'selectors'	=> [
					'{{WRAPPER}} .dtr-servicebox__subtitle, {{WRAPPER}} .dtr-servicebox__desc'	=> 'color: {{VALUE}};',
				],
			]
		);
		
		$this->add_group_control(
            Group_Control_Typography::get_type(),
            [
                'name' 		=> 'heading_typo',
				'label' 	=> esc_html__( 'Heading / On Hover heading Typography', 'copr' ),
                'selector' 	=> '{{WRAPPER}} .dtr-servicebox__title, {{WRAPPER}} .dtr-servicebox__subtitle',
            ]
        );
		
		$this->add_group_control(
            Group_Control_Typography::get_type(),
            [
                'name' 		=> 'content_typo',
				'label' 	=> esc_html__( 'Content Typography', 'copr' ),
                'selector' 	=> '{{WRAPPER}} .dtr-servicebox__desc',
            ]
        );

		$this->end_controls_section();
		// style control ends
		
	}

	/**
	 * Render widget output on the frontend.
	 * Written in PHP and used to generate the final HTML.
	 * @access protected
	 */
	protected function render() {
		$settings = $this->get_settings(); 
		if ( ! empty( $settings['custom_icon'] ) ) {
		$this->add_render_attribute( 'custom_icon', 'class', 'dtr-icon' );
		$this->add_render_attribute( 'custom_icon', 'class', $settings['custom_icon'] );
		$this->add_render_attribute( 'custom_icon', 'aria-hidden', 'true' ); } ?>
        <div class="dtr-servicebox-wrapper <?php echo esc_attr( $settings['preset_color_scheme'] ) ?>">
            <div class="dtr-servicebox">
            	<div class="dtr-servicebox__icon-wrapper"></div>
				<?php if ( $settings['servicebox_icon_type'] == 'dtr-icon-type-icon' ) { ?>
                <div class="dtr-servicebox__icon"><?php Icons_Manager::render_icon( $settings['default_icon'], [ 'aria-hidden' => 'true' ] ); ?></div>
                <?php } elseif ( $settings['servicebox_icon_type'] == 'dtr-icon-type-theme-icon' ) { ?>
                <div class="dtr-servicebox__icon"><i <?php echo $this->get_render_attribute_string( 'custom_icon' ) ?>></i></div>
                <?php } elseif ( $settings['servicebox_icon_type'] == 'dtr-icon-type-img' && ! empty( $settings['icon_image']['url'] ) ) { ?>
                <div class="dtr-servicebox__icon  dtr-servicebox__icon-has-img">
                <?php
                $this->add_render_attribute( 'icon_image', 'src', $settings['icon_image']['url'] );
                $this->add_render_attribute( 'icon_image', 'alt', Control_Media::get_image_alt( $settings['icon_image'] ) );
                $this->add_render_attribute( 'icon_image', 'title', Control_Media::get_image_title( $settings['icon_image'] ) );
                $icon_image_html = Group_Control_Image_Size::get_attachment_image_html( $settings, 'icon_thumbnail', 'icon_image' ); ?>
                <?php echo $icon_image_html ?> 
                </div> 
                <?php } elseif ( $settings['servicebox_icon_type'] == 'dtr-icon-type-html' ) { ?>
                <div class="dtr-servicebox__icon">
                <?php echo wp_kses_post( $settings['servicebox_icon_type_html'] ); ?>
                </div>
                <?php } ?>
				<?php if ( ! empty( $settings['servicebox_heading'] ) ) { ?>
                <<?php echo esc_attr( $settings['heading_size'] ) ?> class="dtr-servicebox__title"><?php echo wp_kses_post( $settings['servicebox_heading'] ) ?></<?php echo esc_attr( $settings['heading_size'] ) ?>>
                <?php } ?>
                <div class="dtr-servicebox__content">
                    <<?php echo esc_attr( $settings['heading_size'] ) ?> class="dtr-servicebox__subtitle"><?php echo wp_kses_post( $settings['servicebox_heading'] ) ?></<?php echo esc_attr( $settings['heading_size'] ) ?>>
                    <?php if ( ! empty( $settings['servicebox_content'] ) ) { ?>
                    <div class="dtr-servicebox__desc"><?php echo wp_kses_post( $settings['servicebox_content'] ) ?></div>
                    <?php } ?>
                </div>
                <div class="dtr-servicebox__img">
					<?php
                    $this->add_render_attribute( 'image', 'src', $settings['image']['url'] );
                    $this->add_render_attribute( 'image', 'alt', Control_Media::get_image_alt( $settings['image'] ) );
                    $this->add_render_attribute( 'image', 'title', Control_Media::get_image_title( $settings['image'] ) );
                    $image_html = Group_Control_Image_Size::get_attachment_image_html( $settings, 'thumbnail', 'image' ); ?>
                    <?php echo $image_html ?> 
                </div>
            </div>
        </div>
	<?php
		}
	
		/**
		 * Render widget output in the editor.
		 * Written as a Backbone JavaScript template and used to generate the live preview.
		 * @access protected
		 */
		protected function content_template() {
		?>
        <div class="dtr-servicebox-wrapper {{{settings.preset_color_scheme }}}">
            <div class="dtr-servicebox"> 
				<div class="dtr-servicebox__icon-wrapper"></div>
                <# if( settings.servicebox_icon_type == 'dtr-icon-type-icon' ) {
                iconHTML = elementor.helpers.renderIcon( view, settings.default_icon, { 'aria-hidden': true }, 'i' , 'object' ); #>
                	<div class="dtr-servicebox__icon">{{{ iconHTML.value }}}</div>
                <# } else if( settings.servicebox_icon_type == 'dtr-icon-type-theme-icon' ) { #>
                	<div class="dtr-servicebox__icon"><i class="{{ settings.custom_icon }}"></i></div>
                <# } else if( settings.servicebox_icon_type == 'dtr-icon-type-img' )  {
                    if ( settings.icon_image.url ) {
                    var icon_image = {
                    id: settings.icon_image.id,
                    url: settings.icon_image.url,
                    size: settings.icon_thumbnail_size,
                    dimension: settings.icon_thumbnail_custom_dimension,
                    model: view.getEditModel()
                    };
					var icon_image_url = elementor.imagesManager.getImageUrl( icon_image );
                } #>
                	<div class="dtr-servicebox__icon dtr-servicebox__icon-has-img"><img src="{{ icon_image_url }}"/></div>
                <# } else if( settings.servicebox_icon_type == 'dtr-icon-type-html' ) { #>	
                	<div class="dtr-servicebox__icon">{{{ settings.servicebox_icon_type_html }}}</div>
                <# } #>	
            	
                <# if ( settings.servicebox_heading ) { #>
                    <{{ settings.heading_size }} class="dtr-servicebox__title">{{{ settings.servicebox_heading }}}</{{ settings.heading_size }}>
                <# } #>
                <div class="dtr-servicebox__content">   
                	<# if ( settings.servicebox_subheading ) { #>
                    	<{{ settings.heading_size }} class="dtr-servicebox__subtitle">{{{ settings.servicebox_subheading }}}</{{ settings.heading_size }}>
                	<# } #> 
                    <# if ( settings.servicebox_content ) { #>
                        <div class="dtr-servicebox__desc">{{{ settings.servicebox_content }}}</div>
                    <# } #>
                </div>
                <#  if ( settings.image.url ) {
                var image = {
                id: settings.image.id,
                url: settings.image.url,
                size: settings.thumbnail_size,
                dimension: settings.thumbnail_custom_dimension,
                model: view.getEditModel()
                };
                var image_url = elementor.imagesManager.getImageUrl( image ); #>
                <div class="dtr-servicebox__img"><img src="{{ image_url }}"/></div>
                <# } #> 
            </div>
        </div>
<?php
	}
}