<?php
namespace CoprAddons\Widgets;

use Elementor\Widget_Base;
use Elementor\Controls_Manager;
use Elementor\Utils;
use Elementor\Group_Control_Typography;
use Elementor\Repeater;

if ( ! defined( 'ABSPATH' ) ) {
	exit; // Exit if accessed directly.
}

/**
 * Widget
 */
class Copr_Skills extends Widget_Base {

	/**
	 * Retrieve widget name.
	 * @access public
	 * @return string Widget name.
	 */
	public function get_name() {
		return 'dtr-skills';
	}

	/**
	 * Retrieve widget title.
	 * @access public
	 * @return string Widget title.
	 */
	public function get_title() {
		return esc_html__( 'Skills', 'copr' );
	}

	/**
	 * Retrieve widget icon.
	 * @access public
	 * @return string Widget icon.
	 */
	public function get_icon() {
		return 'eicon-favorite';
	}

	/**
	 * Retrieve the list of categories widget belongs to.
	 * Used to determine where to display the widget in the editor.
	 * @access public
	 * @return array Widget categories.
	 */
	public function get_categories() {
		return array('dtr-element');
	}
	

	/**
	 * Register widget controls.
	 * Adds different input fields to allow the user to change and customize the widget settings.
	 * @access protected
	 */
	protected function register_controls() {
	
		// content control starts
		$this->start_controls_section(
			'section_main_content_skills',
			[
				'label'	=> esc_html__( 'Skills', 'copr' ),
			]
		);

		$repeater = new Repeater();

		$repeater->add_control(
			'heading',
			[
				'label' => __( 'Heading', 'copr' ),
				'type' => Controls_Manager::TEXT,
				'label_block' => true,
				'placeholder' => __( 'Heading', 'copr' ),
				'default' => __( 'Skills Heading', 'copr' ),
			]
		);
		
		$repeater->add_control(
			'skills_points',
			[
				'label' => esc_html__( 'Points On Scale', 'copr' ),
				'type' => Controls_Manager::SELECT,
				'default' => 'dtr-skills--10points',
				'label_block' => true,
				'options' => [
					'dtr-skills--10points'	=> esc_html__( '10', 'copr' ),
					'dtr-skills--9points' 	=> esc_html__( '9', 'copr' ),
					'dtr-skills--8points'	=> esc_html__( '8', 'copr' ),
					'dtr-skills--7points' 	=> esc_html__( '7', 'copr' ),
					'dtr-skills--6points'	=> esc_html__( '6', 'copr' ),
					'dtr-skills--5points' 	=> esc_html__( '5', 'copr' ),
					'dtr-skills--4points'	=> esc_html__( '4', 'copr' ),
					'dtr-skills--3points' 	=> esc_html__( '3', 'copr' ),
					'dtr-skills--2points'	=> esc_html__( '2', 'copr' ),
					'dtr-skills--1points' 	=> esc_html__( '1', 'copr' ),
				],
			]
		);
		
		$this->add_control(
			'skills',
			[
				'label' => __( 'Items', 'copr' ),
				'type' => Controls_Manager::REPEATER,
				'fields' => $repeater->get_controls(),
				'default' => [
					[
						'heading' => __( 'Skills Item #1', 'copr' ),
					],
					[
						'heading' => __( 'Skills Item #2', 'copr' ),
					],
					[
						'heading' => __( 'Skills Item #3', 'copr' ),
					],
				],
				'title_field' => '{{{ heading }}}',
			]
		);
		
		$this->add_control(
			'heading_min_width',
			[
				'label' => esc_html__( 'Heading Column Min Width', 'copr' ),
				'type' => Controls_Manager::SLIDER,
				'range' => [
					'%' => [
						'max' => 50,
					],
				],
				'default' => [
					'size' => '',
					'size_units' => '%',
				],
				'size_units' => [ 'px', '%' ],
				'selectors' => [
					'{{WRAPPER}} .dtr-skills__heading' => 'min-width: {{SIZE}}{{UNIT}};',
				],
			]
		);
		
		$this->add_control(
			'view',
			[
				'label' 	=> esc_html__( 'View', 'copr' ),
				'type' 		=> Controls_Manager::HIDDEN,
				'default'	=> 'traditional',
			]
		);
		
		$this->end_controls_section();
		// content control ends

		// style control starts
		$this->start_controls_section(
			'section_main_content_styles',
			[
				'label'	=> esc_html__( 'Styles', 'copr' ),
				'tab'   => Controls_Manager::TAB_STYLE,
			]
		);
		
		$this->add_control(
			'heading_style_control',
			[
				'label' => __( 'Heading', 'copr' ),
				'type' => Controls_Manager::HEADING,
				'separator' => '',
			]
		);
		
		$this->add_control(
			'heading_color',
			[
				'label' 	=> esc_html__( 'Color', 'copr' ),
				'default' 	=> '',
				'type' 		=> Controls_Manager::COLOR,
				'selectors'	=> [
					'{{WRAPPER}} .dtr-skills__heading'	=> 'color: {{VALUE}};',
				],
			]
		);

		$this->add_group_control(
            Group_Control_Typography::get_type(),
            [
                'name' 		=> 'heading_typo',
				'label' 	=> esc_html__( 'Typography', 'copr' ),
                'selector'	=> '{{WRAPPER}} .dtr-skills__heading',
            ]
        );
		
		$this->add_control(
			'dots_style_control',
			[
				'label' => __( 'Dots', 'copr' ),
				'type' => Controls_Manager::HEADING,
				'separator' => 'before',
			]
		);
		
		$this->add_control(
			'active_dots_color',
			[
				'label' 	=> esc_html__( 'Active Dots Color', 'copr' ),
				'default' 	=> '',
				'type' 		=> Controls_Manager::COLOR,
				'selectors'	=> [
					'{{WRAPPER}} .dtr-skills__dots::before'	=> 'color: {{VALUE}};',
				],
			]
		);
		
		$this->add_control(
			'inactive_dots_color',
			[
				'label' 	=> esc_html__( 'Disabled Dots Color', 'copr' ),
				'default' 	=> '',
				'type' 		=> Controls_Manager::COLOR,
				'selectors'	=> [
					'{{WRAPPER}} .dtr-skills__dots::after'	=> 'color: {{VALUE}};',
				],
			]
		);

		$this->end_controls_section();
		// style control ends
		
	}

	/**
	 * Render widget output on the frontend.
	 * Written in PHP and used to generate the final HTML.
	 * @access protected
	 */
	protected function render() {
		$settings = $this->get_settings_for_display();
		?>
        <div class="dtr-skills-wrapper">
			<?php foreach ( $settings['skills'] as $index => $item ) : ?>
            <div class="dtr-skills <?php echo esc_attr( $item['skills_points'] ); ?>">
            <?php if ( ! empty( $item['heading'] ) ) { ?>
               <p class="dtr-skills__heading"><?php echo esc_html( $item['heading'] ) ?></p>
            <?php } ?>
                <div class="dtr-skills__dots"></div>
            </div>
            <?php endforeach; ?>
        </div>
		<?php
	}

	/**
	 * Render widget output in the editor.
	 * Written as a Backbone JavaScript template and used to generate the live preview.
	 * @access protected
	 */
	protected function content_template() {
		?>
        <# if ( settings.skills ) { #>
            <div class="dtr-skills-wrapper">
                <# _.each( settings.skills, function( item, index ) { #>
                <div class="dtr-skills {{ item.skills_points }}">
                <p class="dtr-skills__heading">{{{item.heading }}}</p>
                <div class="dtr-skills__dots"></div>
                </div>
                <# } ); #>
            </div>
        <#	} #>
		<?php
	}
}