<?php
namespace CoprAddons\Widgets;
use Elementor\Widget_Base;
use Elementor\Controls_Manager;
use Elementor\Utils;
use Elementor\Group_Control_Typography;

if ( ! defined( 'ABSPATH' ) ) {
	exit; // Exit if accessed directly.
}
/**
 * Timeline Widget
 */
class Copr_Timeline extends Widget_Base {

	/**
	 * Retrieve widget name.
	 * @access public
	 * @return string Widget name.
	 */
	public function get_name() {
		return 'dtr-timeline';
	}

	/**
	 * Retrieve widget title.
	 * @access public
	 * @return string Widget title.
	 */
	public function get_title() {
		return esc_html__( 'Timeline Item', 'copr' );
	}

	/**
	 * Retrieve widget icon.
	 * @access public
	 * @return string Widget icon.
	 */
	public function get_icon() {
		return 'eicon-favorite';
	}

	/**
	 * Retrieve the list of categories widget belongs to.
	 * Used to determine where to display the widget in the editor.
	 * @access public
	 * @return array Widget categories.
	 */
	public function get_categories() {
		  return array('dtr-element');

	}

	/**
	 * Register widget controls.
	 * Adds different input fields to allow the user to change and customize the widget settings.
	 * @access protected
	 */
	protected function register_controls() {
		
		// content control starts
		$this->start_controls_section(
			'section_timeline_content',
			[
				'label'	=> esc_html__( 'Timeline Item', 'copr' ),
			]
		);
		
		$this->add_control(
			'timeline_highlight',
			[
				'label' 		=> esc_html__( 'Highlighted Text', 'copr' ),
				'type' 			=> Controls_Manager::TEXT,
				'default' 		=> esc_html__( '2020 - 2030', 'copr' ),
				'placeholder'	=> esc_html__( '2020 - 2030', 'copr' ),
				'label_block' 	=> true,
			]
		);
		
		$this->add_control(
			'timeline_heading',
			[
				'label' 		=> esc_html__( 'Heading', 'copr' ),
				'type' 			=> Controls_Manager::TEXT,
				'default' 		=> esc_html__( 'Heading Goes Here', 'copr' ),
				'placeholder'	=> esc_html__( 'Heading', 'copr' ),
				'label_block' 	=> true,
				'separator' 	=> 'before',
			]
		);
		
		$this->add_control(
			'heading_size',
			[
				'label' 	=> esc_html__( 'Heading - HTML Tag', 'elementor' ),
				'type' 		=> Controls_Manager::SELECT,
				'options'	=> [
					'h1' 	=> 'H1',
					'h2' 	=> 'H2',
					'h3' 	=> 'H3',
					'h4' 	=> 'H4',
					'h5' 	=> 'H5',
					'h6'	=> 'H6',
					'p' 	=> 'p',
				],
				'default' => 'h5',
			]
		);

		$this->add_control(
			'timeline_content',
			[
				'label' 		=> esc_html__( 'Content', 'copr' ),
				'type' 			=> Controls_Manager::TEXTAREA,
				'default' 		=> esc_html__( 'Content Goes Here', 'copr' ),
				'placeholder'	=> esc_html__( 'Content', 'copr' ),
				'separator' 	=> 'before',
				'label_block' 	=> true,
			]
		);

		$this->add_control(
			'view',
			[
				'label' 	=> esc_html__( 'View', 'copr' ),
				'type' 		=> Controls_Manager::HIDDEN,
				'default'	=> 'traditional',
			]
		);
		
		$this->end_controls_section();

		// style control starts
		$this->start_controls_section(
			'section_style_content',
			[
				'label'	=> esc_html__( 'Styles', 'copr' ),
				'tab'   => Controls_Manager::TAB_STYLE,
			]
		);

		$this->add_control(
			'timeline_highlight_style',
			[
				'label' => esc_html__( 'Timeline Highlight', 'copr' ),
				'type' 	=> Controls_Manager::HEADING,
			]
		);
		
		$this->add_control(
			'preset_color_scheme',
			[
				'label' 	=> esc_html__( 'Preset Color Scheme', 'copr' ),
				'type'		=> Controls_Manager::SELECT,
				'default'	=> '',
				'options' 	=> [
					'color-scheme3'	=> esc_html__( 'Primary', 'copr' ),
					''				=> esc_html__( 'Secondary', 'copr' ),
					'color-scheme1'	=> esc_html__( 'Secondary Light', 'copr' ),
				],
			]
		);
		
		$this->add_control(
			'timeline_highlight_bg_color',
			[
				'label' 	=> esc_html__( 'Background Color', 'copr' ),
				'default' 	=> '',
				'type' 		=> Controls_Manager::COLOR,
				'selectors'	=> [
					'{{WRAPPER}} .dtr-timeline__highlight'	=> 'background-color: {{VALUE}};',
				],
			]
		);
		
		$this->add_control(
			'timeline_highlight_color',
			[
				'label' 	=> esc_html__( 'Color', 'copr' ),
				'default' 	=> '',
				'type' 		=> Controls_Manager::COLOR,
				'selectors'	=> [
					'{{WRAPPER}} .dtr-timeline__highlight'	=> 'color: {{VALUE}};',
				],
			]
		);
		
		$this->add_group_control(
            Group_Control_Typography::get_type(),
            [
                'name' 		=> 'timeline_highlight_typo',
				'label' 	=> esc_html__( 'Typography', 'copr' ),
                'selector'	=> '{{WRAPPER}} .dtr-timeline__highlight',
            ]
        );
		
		// heading
		$this->add_control(
			'heading_style',
			[
				'label' => esc_html__( 'Heading', 'copr' ),
				'type' 	=> Controls_Manager::HEADING,
				'separator' => 'before',
			]
		);

		$this->add_control(
			'heading_color',
			[
				'label' 	=> esc_html__( 'Color', 'copr' ),
				'default' 	=> '',
				'type' 		=> Controls_Manager::COLOR,
				'selectors'	=> [
					'{{WRAPPER}} .dtr-timeline__heading'	=> 'color: {{VALUE}};',
				],
			]
		);
		
		$this->add_group_control(
            Group_Control_Typography::get_type(),
            [
                'name' 		=> 'main_heading_typo',
				'label' 	=> esc_html__( 'Typography', 'copr' ),
                'selector'	=> '{{WRAPPER}} .dtr-timeline__heading',
            ]
        );

		// text
		$this->add_control(
			'timeline_content_style',
			[
				'label' => esc_html__( 'Content', 'copr' ),
				'type' 	=> Controls_Manager::HEADING,
				'separator' => 'before',
			]
		);
		
		$this->add_control(
			'timeline_content_color',
			[
				'label' 	=> esc_html__( 'Color', 'copr' ),
				'default' 	=> '',
				'type' 		=> Controls_Manager::COLOR,
				'selectors'	=> [
					'{{WRAPPER}} .dtr-timeline__content'	=> 'color: {{VALUE}};',
				],
			]
		);
		
		$this->add_group_control(
            Group_Control_Typography::get_type(),
            [
                'name' 		=> 'timeline_content_typo',
				'label' 	=> esc_html__( 'Typography', 'copr' ),
                'selector'	=> '{{WRAPPER}} .dtr-timeline__content',
            ]
        );
		
		$this->end_controls_section();
		// style control ends
	}

	/**
	 * Render widget output on the frontend.
	 * Written in PHP and used to generate the final HTML.
	 * @access protected
	 */
	protected function render() {
		$settings = $this->get_settings();
	  	?>
		<div class="dtr-timeline">
        <?php if ( ! empty( $settings['timeline_highlight'] ) ) { ?>
        	<span class="dtr-timeline__highlight <?php echo esc_attr( $settings['preset_color_scheme'] ) ?>"><?php echo esc_html( $settings['timeline_highlight'] ) ?></span>
        <?php } ?>
        <?php if ( ! empty( $settings['timeline_heading'] ) ) { ?>
    		<<?php echo esc_attr( $settings['heading_size'] ) ?> class="dtr-timeline__heading"><?php echo esc_html( $settings['timeline_heading'] ) ?></<?php echo esc_attr( $settings['heading_size'] ) ?>>
        <?php } ?>
        <?php if ( ! empty( $settings['timeline_content'] ) ) { ?>
     		<div class="dtr-timeline__content"><?php echo wp_kses_post( $settings['timeline_content'] ) ?></div>
        <?php } ?>
		</div>
<?php
	}

	/**
	 * Render widget output in the editor.
	 * Written as a Backbone JavaScript template and used to generate the live preview.
	 * @access protected
	 */
	protected function content_template() {
		?>
	<div class="dtr-timeline">
        <# if ( settings.timeline_highlight ) { #>
    		<span class="dtr-timeline__highlight {{{settings.preset_color_scheme }}}">{{{settings.timeline_highlight }}}</span>
        <# } #>
        <# if ( settings.timeline_heading ) { #>
			<{{ settings.heading_size }} class="dtr-timeline__heading">{{{settings.timeline_heading }}}</{{ settings.heading_size }}>
        <# } #>
        <# if ( settings.timeline_content ) { #>
			<div class="dtr-timeline__content">{{{settings.timeline_content }}}</div>
        <# } #>
	</div>
<?php
	}
}